"""
Tests
"""

import pytest

from ArWikiCats.new_resolvers.sports_resolvers.raw_sports import resolve_sport_label_unified
from utils.dump_runner import make_dump_test_name_data_callback

test_data_1 = {
    "australian rules football owners and executives": "رؤساء تنفيذيون وملاك كرة قدم أسترالية",
    "australian rules football awards": "جوائز كرة قدم أسترالية",
    "baseball commissioners": "مفوضو كرة قاعدة",
    "baseball music": "موسيقى كرة قاعدة",
    "baseball video games": "ألعاب فيديو كرة قاعدة",
    "basketball awards": "جوائز كرة سلة",
    "basketball comics": "قصص مصورة كرة سلة",
    "basketball terminology": "مصطلحات كرة سلة",
    "bowling broadcasters": "مذيعو بولينج",
    "bowling television series": "مسلسلات تلفزيونية بولينج",
    "canoeing logos": "شعارات ركوب الكنو",
    "cycling television series": "مسلسلات تلفزيونية سباق دراجات هوائية",
    "fencing logos": "شعارات مبارزة سيف شيش",
    "figure skating media": "إعلام تزلج فني",
    "football governing bodies": "هيئات تنظيم كرة قدم",
    "go comics": "قصص مصورة غو",
    "muay thai video games": "ألعاب فيديو موياي تاي",
    "roller hockey logos": "شعارات هوكي دحرجة",
    "rowing equipment": "معدات تجديف",
    "rugby union stadiums": "ملاعب اتحاد رجبي",
    "shooting sports equipment": "معدات رماية",
    "snooker terminology": "مصطلحات سنوكر",
    "tennis logos": "شعارات كرة مضرب",
    "water polo comics": "قصص مصورة كرة ماء",
    "water polo competition": "منافسات كرة ماء",
    "wheelchair basketball terminology": "مصطلحات كرة سلة على كراسي متحركة",
}

data_2 = {
    "australian rules football owners and executives": "رؤساء تنفيذيون وملاك كرة قدم أسترالية",
    "australian rules football awards": "جوائز كرة قدم أسترالية",
    "baseball commissioners": "مفوضو كرة قاعدة",
    "baseball music": "موسيقى كرة قاعدة",
    "baseball video games": "ألعاب فيديو كرة قاعدة",
    "basketball awards": "جوائز كرة سلة",
    "basketball comics": "قصص مصورة كرة سلة",
    "basketball terminology": "مصطلحات كرة سلة",
    "bowling broadcasters": "مذيعو بولينج",
    "bowling television series": "مسلسلات تلفزيونية بولينج",
    "canoeing logos": "شعارات ركوب الكنو",
    "cycling television series": "مسلسلات تلفزيونية سباق دراجات هوائية",
    "fencing logos": "شعارات مبارزة سيف شيش",
    "figure skating media": "إعلام تزلج فني",
    "football governing bodies": "هيئات تنظيم كرة قدم",
    "go comics": "قصص مصورة غو",
    "muay thai video games": "ألعاب فيديو موياي تاي",
    "roller hockey logos": "شعارات هوكي دحرجة",
    "rowing equipment": "معدات تجديف",
    "rugby union stadiums": "ملاعب اتحاد رجبي",
    "shooting sports equipment": "معدات رماية",
    "snooker terminology": "مصطلحات سنوكر",
    "tennis logos": "شعارات كرة مضرب",
    "water polo comics": "قصص مصورة كرة ماء",
    "water polo competition": "منافسات كرة ماء",
    "wheelchair basketball terminology": "مصطلحات كرة سلة على كراسي متحركة",
    "shooting sports racing organizations": "منظمات سباق رماية",
    "roller hockey (quad) comics": "قصص مصورة هوكي دحرجة",
    "handball racing leagues": "دوريات سباق كرة يد",
    "cross country fan clubs": "أندية معجبي عدو ريفي",
    "track and field video games": "ألعاب فيديو سباقات مضمار وميدان",
    "football racing variants": "أشكال سباق كرة قدم",
    "hurling lists": "قوائم قذف",
    "triple jump racing leagues seasons": "مواسم دوريات سباق قفز ثلاثي",
    "boules songs": "أغاني بوتشي",
    "submission wrestling racing managers": "مدربو سباق مصارعة خضوع",
    "football equipment": "معدات كرة قدم",
    "auto racing bodies": "هيئات سباق سيارات",
    "track and field tactics and skills": "مهارات سباقات مضمار وميدان",
    "soft tennis racing logos": "شعارات سباق كرة مضرب لينة",
    "canadian football racing owners": "ملاك سباق كرة قدم كندية",
    "mixed martial arts racing referees": "حكام سباق فنون قتال مختلطة",
    "baseball racing tactics and skills": "مهارات سباق كرة قاعدة",
    "mountain bike racing films": "أفلام سباق الدراجات الجبلية",
    "sepak takraw manager history": "تاريخ مدربو سيباك تاكرو",
    "sledge hockey manager history": "تاريخ مدربو هوكي مزلجة",
    "snooker racing owners": "ملاك سباق سنوكر",
    "kurash racing commissioners": "مفوضو سباق كوراش",
    "motorcycle racing people": "أعلام سباق دراجات نارية",
    "table tennis racing television series": "مسلسلات تلفزيونية سباق كرة طاولة",
    "go racing managers": "مدربو سباق غو",
    "aquatics racing umpires": "حكام سباق رياضات مائية",
    "pole vault players": "لاعبو قفز بالزانة",
    "archery seasons": "مواسم نبالة",
    "track-and-field athletics racing clubs and teams": "أندية وفرق سباق ألعاب قوى مضمار وميدان",
    "canadian-football commentators": "معلقو كرة قدم كندية",
    "modern pentathlon racing people": "أعلام سباق خماسي حديث",
    "rugby league racing logos": "شعارات سباق دوري رجبي",
    "equestrian racing organizations": "منظمات سباق فروسية",
    "running referees": "حكام ركض",
    "lawn bowls tactics and skills": "مهارات بولينغ عشبي",
    "formula e racing non-playing staff": "طاقم سباق فورمولا إي غير اللاعبين",
    "pentathlon television series": "مسلسلات تلفزيونية خماسي",
    "shooting sport racing variants": "أشكال سباق رماية",
    "boccia racing coaches": "مدربو سباق بوتشيا",
    "single skating owners and executives": "رؤساء تنفيذيون وملاك تزلج فردي على الجليد",
    "javelin throw racing championships": "بطولات سباق رمي رمح",
    "rowing racing people": "أعلام سباق تجديف",
    "snowboarding racing referees": "حكام سباق تزلج على الثلوج",
    "long-distance running racing media": "إعلام سباق ركض مسافات طويلة",
    "wheelchair fencing fan clubs": "أندية معجبي مبارزة سيف شيش على كراسي متحركة",
    "bowls logos": "شعارات بولينج",
    "javelin throw video games": "ألعاب فيديو رمي رمح",
    "middle-distance running clubs and teams": "أندية وفرق ركض مسافات متوسطة",
    "shot put results": "نتائج دفع ثقل",
    "skating non-profit organizations": "منظمات غير ربحية تزلج",
    "cycle manager": "مدربو دراجات",
    "skateboarding owners": "ملاك تزلج على اللوح",
    "track and field bodies": "هيئات سباقات مضمار وميدان",
    "orienteering players": "لاعبو سباق موجه",
    "alpine skiing racing players": "لاعبو سباق تزلج على المنحدرات الثلجية",
    "greco-roman wrestling racing music": "موسيقى سباق مصارعة يونانية رومانية",
    "motocross tactics and skills": "مهارات موتو كروس",
    "pencak silat television series": "مسلسلات تلفزيونية بنكات سيلات",
    "ski jumping racing films": "أفلام سباق قفز تزلجي",
    "darts racing equipment": "معدات سباق سهام مريشة",
    "high school racing personnel": "أفراد سباق مدارس ثانوية",
    "nordic combined lists": "قوائم تزلج نوردي مزدوج",
    "formula racing comics": "قصص مصورة سباقات فورمولا",
    "artistic gymnastics television series": "مسلسلات تلفزيونية جمباز فني",
    "windsurfing racing non-profit organizations": "منظمات غير ربحية سباق ركوب قوارب شراعية",
    "hockey racing equipment": "معدات سباق هوكي",
    "bouldering variants": "أشكال بولدرنق",
    "roller skating players": "لاعبو تزلج بالعجلات",
    "cricket racing video games": "ألعاب فيديو سباق كريكت",
    "shot put racing bodies": "هيئات سباق دفع ثقل",
    "synchronized swimming personnel": "أفراد سباحة متزامنة",
    "cycle racing non-playing staff": "طاقم سباق دراجات غير اللاعبين",
    "aerobics racing manager": "مدربو سباق جمباز أيروبيكس",
    "motorcycle players": "لاعبو دراجات نارية",
    "canadian-football players": "لاعبو كرة قدم كندية",
    "muay thai championships": "بطولات موياي تاي",
    "wheelchair curling logos": "شعارات كيرلنغ على كراسي متحركة",
    "rugby football racing commentators": "معلقو سباق كرة قدم رجبي",
    "road bicycle racing comics": "قصص مصورة سباق دراجات على الطريق",
    "formula one culture": "ثقافة فورمولا ون",
    "skiing logos": "شعارات تزلج",
    "diving racing music": "موسيقى سباق غطس",
    "modern pentathlon racing world competitions": "منافسات سباق خماسي حديث عالمية",
    "bowls executives": "مدراء بولينج",
    "climbing racing terminology": "مصطلحات سباق تسلق",
    "road bicycle racing video games": "ألعاب فيديو سباق دراجات على الطريق",
    "association football racing trainers": "مدربو سباق كرة قدم",
    "pole vault racing logos": "شعارات سباق قفز بالزانة",
    "acrobatic gymnastics racing songs": "أغاني سباق جمباز اكروباتيكي",
    "baseball variants": "أشكال كرة قاعدة",
    "underwater hockey racing referees": "حكام سباق هوكي تحت الماء",
    "cycle racing players": "لاعبو سباق دراجات",
    "motorboat racing organizations": "منظمات سباق زوارق نارية",
    "beach volleyball lists": "قوائم كرة طائرة شاطئية",
    "floorball manager history": "تاريخ مدربو كرة أرض",
    "sumo racing trainers": "مدربو سباق سومو",
    "cricket racing non-profit publishers": "ناشرون غير ربحيون سباق كريكت",
    "boxing media": "إعلام بوكسينغ",
    "biathlon racing non-profit publishers": "ناشرون غير ربحيون سباق بياثلون",
    "beach soccer racing owners and executives": "رؤساء تنفيذيون وملاك سباق كرة قدم شاطئية",
    "ju-jitsu racing manager": "مدربو سباق جوجوتسو",
    "tennis racing footballers": "لاعبو سباق كرة مضرب",
    "track-and-field athletics racing players": "لاعبو سباق ألعاب قوى مضمار وميدان",
    "canoeing racing coaches": "مدربو سباق ركوب الكنو",
    "jujutsu racing music": "موسيقى سباق جوجوتسو",
    "cross country running films": "أفلام عدو ريفي",
    "snowboarding commissioners": "مفوضو تزلج على الثلوج",
    "short track speed skating coaches": "مدربو تزلج على مسار قصير",
    "martial arts racing culture": "ثقافة سباق فنون قتالية",
    "sumo songs": "أغاني سومو",
    "racquetball racing governing bodies": "هيئات تنظيم سباق كرة الراح",
    "equestrianism racing songs": "أغاني سباق فروسية",
    "futsal clubs and teams": "أندية وفرق كرة صالات",
    "go racing executives": "مدراء سباق غو",
    "ju-jitsu racing equipment": "معدات سباق جوجوتسو",
    "cue sports racing teams": "فرق سباق بلياردو",
    "roller skating racing world competitions": "منافسات سباق تزلج بالعجلات عالمية",
    "aerobics logos": "شعارات جمباز أيروبيكس",
    "lawn bowls racing governing bodies": "هيئات تنظيم سباق بولينغ عشبي",
    "high school executives": "مدراء مدارس ثانوية",
    "wheelchair handball results": "نتائج كرة يد على كراسي متحركة",
    "weightlifting clubs and teams": "أندية وفرق رفع أثقال",
    "running logos": "شعارات ركض",
    "pencak silat matches": "مباريات بنكات سيلات",
    "volleyball racing matches": "مباريات سباق كرة طائرة",
    "sumo people": "أعلام سومو",
    "skateboarding records and statistics": "سجلات وإحصائيات تزلج على اللوح",
    "cricket racing umpires": "حكام سباق كريكت",
    "track-and-field athletics manager history": "تاريخ مدربو ألعاب قوى مضمار وميدان",
    "racquetball players": "لاعبو كرة الراح",
    "rally racing rivalries": "دربيات سباق رالي",
    "croquet racing tactics and skills": "مهارات سباق كروكيت",
    "climbing racing personnel": "أفراد سباق تسلق",
    "boules racing results": "نتائج سباق بوتشي",
    "freestyle skiing racing people": "أعلام سباق تزلج حر",
    "curling world competitions": "منافسات كيرلنغ عالمية",
    "synchronized swimming racing players": "لاعبو سباق سباحة متزامنة",
    "skateboarding racing variants": "أشكال سباق تزلج على اللوح",
    "biathlon culture": "ثقافة بياثلون",
    "wrestling racing equipment": "معدات سباق مصارعة",
    "roller skating lists": "قوائم تزلج بالعجلات",
    "wrestling racing awards": "جوائز سباق مصارعة",
    "gaelic football stadiums": "ملاعب كرة قدم غالية",
    "floorball racing comics": "قصص مصورة سباق كرة أرض",
    "roller hockey (quad) world competitions": "منافسات هوكي دحرجة عالمية",
    "long-distance running racing broadcasters": "مذيعو سباق ركض مسافات طويلة",
    "roller hockey media": "إعلام هوكي دحرجة",
    "silat bodies": "هيئات سيلات",
    "hockey commentators": "معلقو هوكي",
    "dressage seasons": "مواسم ترويض خيول",
    "rugby union lists": "قوائم اتحاد رجبي",
    "alpine skiing records and statistics": "سجلات وإحصائيات تزلج على المنحدرات الثلجية",
    "pole vault music": "موسيقى قفز بالزانة",
    "skating people": "أعلام تزلج",
    "weightlifting variants": "أشكال رفع أثقال",
    "hurling records and statistics": "سجلات وإحصائيات قذف",
    "wheelchair handball clubs and teams": "أندية وفرق كرة يد على كراسي متحركة",
    "ski jumping managers": "مدربو قفز تزلجي",
    "rugbyunion results": "نتائج اتحاد رجبي",
    "triple jump racing commentators": "معلقو سباق قفز ثلاثي",
    "kabaddi footballers": "لاعبو كابادي",
    "bobsleigh fan clubs": "أندية معجبي زلاجة جماعية",
    "triathlon manager history": "تاريخ مدربو سباق ثلاثي",
    "triple jump broadcasters": "مذيعو قفز ثلاثي",
    "floorball records and statistics": "سجلات وإحصائيات كرة أرض",
    "muay thai racing governing bodies": "هيئات تنظيم سباق موياي تاي",
    "beach soccer competitions": "منافسات كرة قدم شاطئية",
    "sprinting racing comics": "قصص مصورة سباق جري سريع",
    "skateboarding governing bodies": "هيئات تنظيم تزلج على اللوح",
    "muay thai seasons": "مواسم موياي تاي",
    "kick boxing comics": "قصص مصورة كيك بوكسينغ",
    "tennis racing variants": "أشكال سباق كرة مضرب",
    "kurash organizations": "منظمات كوراش",
    "rugby league racing films": "أفلام سباق دوري رجبي",
    "netball music": "موسيقى كرة شبكة",
    "rugby sevens clubs": "أندية سباعيات رجبي",
    "futsal racing players": "لاعبو سباق كرة صالات",
    "biathlon films": "أفلام بياثلون",
    "sledge hockey video games": "ألعاب فيديو هوكي مزلجة",
    "esports fan clubs": "أندية معجبي رياضة إلكترونية",
    "basketball results": "نتائج كرة سلة",
    "long jump racing fan clubs": "أندية معجبي سباق قفز طويل",
    "kabaddi racing organizations": "منظمات سباق كابادي",
    "artistic swimming racing non-profit publishers": "ناشرون غير ربحيون سباق سباحة فنية",
    "sledge hockey racing non-playing staff": "طاقم سباق هوكي مزلجة غير اللاعبين",
    "ice hockey leagues seasons": "مواسم دوريات هوكي جليد",
    "sports managers": "مدربو رياضية",
    "silat racing seasons": "مواسم سباق سيلات",
    "badminton non-profit organizations": "منظمات غير ربحية تنس ريشة",
    "basque pelota racing media": "إعلام سباق كرة باسك",
    "motocross racing owners": "ملاك سباق موتو كروس",
    "jujutsu racing organizations": "منظمات سباق جوجوتسو",
    "climbing governing bodies": "هيئات تنظيم تسلق",
    "mixed martial arts personnel": "أفراد فنون قتال مختلطة",
    "roller hockey (quad) racing variants": "أشكال سباق هوكي دحرجة",
    "cricket comics": "قصص مصورة كريكت",
    "shooting sports tactics and skills": "مهارات رماية",
    "acrobatic gymnastics racing non-profit publishers": "ناشرون غير ربحيون سباق جمباز اكروباتيكي",
    "wheelchair handball records and statistics": "سجلات وإحصائيات كرة يد على كراسي متحركة",
    "skating racing seasons": "مواسم سباق تزلج",
    "climbing commentators": "معلقو تسلق",
    "shooting sport players": "لاعبو رماية",
    "cross country running racing owners and executives": "رؤساء تنفيذيون وملاك سباق عدو ريفي",
    "water skiing racing leagues": "دوريات سباق تزلج على الماء",
    "long-distance running racing terminology": "مصطلحات سباق ركض مسافات طويلة",
    "triple jump competitions": "منافسات قفز ثلاثي",
    "running racing championships": "بطولات سباق ركض",
    "rally raid footballers": "لاعبو رالي رايد",
    "floorball racing commentators": "معلقو سباق كرة أرض",
    "ski jumping non-playing staff": "طاقم قفز تزلجي غير اللاعبين",
    "motorsport comics": "قصص مصورة رياضة محركات",
    "gridiron football coaches": "مدربو كرة قدم أمريكية شمالية",
    "snooker umpires": "حكام سنوكر",
    "rhythmic gymnastics leagues seasons": "مواسم دوريات جمباز إيقاعي",
    "beach soccer racing trainers": "مدربو سباق كرة قدم شاطئية",
    "wrestling racing commissioners": "مفوضو سباق مصارعة",
    "bowling racing broadcasters": "مذيعو سباق بولينج",
    "australian rules football television series": "مسلسلات تلفزيونية كرة قدم أسترالية",
    "muay thai racing manager history": "تاريخ مدربو سباق موياي تاي",
    "formula e racing stadiums": "ملاعب سباق فورمولا إي",
    "canoeing and kayaking racing non-profit publishers": "ناشرون غير ربحيون سباق كانو-كاياك",
    "ball hockey racing video games": "ألعاب فيديو سباق هوكي كرة",
    "rugby union logos": "شعارات اتحاد رجبي",
    "pencak silat racing coaches": "مدربو سباق بنكات سيلات",
    "rugby music": "موسيقى رجبي",
    "alpine skiing racing video games": "ألعاب فيديو سباق تزلج على المنحدرات الثلجية",
    "sailing (sport) referees": "حكام رياضة إبحار",
    "cross country running referees": "حكام عدو ريفي",
    "kick boxing racing manager": "مدربو سباق كيك بوكسينغ",
    "rallying racing comics": "قصص مصورة سباق راليات",
    "acrobatic gymnastics racing commissioners": "مفوضو سباق جمباز اكروباتيكي",
    "track cycling songs": "أغاني سباق الدراجات على المضمار",
    "pentathlon racing commentators": "معلقو سباق خماسي",
    "wheelchair handball lists": "قوائم كرة يد على كراسي متحركة",
    "wrestling leagues": "دوريات مصارعة",
    "wheelchair beach handball executives": "مدراء كرة يد شاطئية على كراسي متحركة",
    "bmx referees": "حكام سباق بي إم إكس",
    "sport climbing leagues": "دوريات تسلق",
    "equestrian racing terminology": "مصطلحات سباق فروسية",
    "chinese martial arts awards": "جوائز فنون قتالية صينية",
    "climbing racing clubs and teams": "أندية وفرق سباق تسلق",
    "hammer throw organizations": "منظمات رمي مطرقة",
    "sepak takraw executives": "مدراء سيباك تاكرو",
    "shooting sport stadiums": "ملاعب رماية",
    "acrobatic gymnastics racing matches": "مباريات سباق جمباز اكروباتيكي",
    "volleyball racing manager": "مدربو سباق كرة طائرة",
    "weightlifting racing governing bodies": "هيئات تنظيم سباق رفع أثقال",
    "bandy commissioners": "مفوضو باندي",
    "snooker racing executives": "مدراء سباق سنوكر",
    "ski-orienteering competition": "منافسات سباق تزلج موجه",
    "archery racing equipment": "معدات سباق نبالة",
    "soft tennis racing non-playing staff": "طاقم سباق كرة مضرب لينة غير اللاعبين",
    "bmx racing commissioners": "مفوضو سباق بي إم إكس",
    "modern pentathlon media": "إعلام خماسي حديث",
    "relay race non-profit organizations": "منظمات غير ربحية سباق تتابع",
    "pesäpallo racing results": "نتائج سباق بيسبالو",
    "wheelchair basketball broadcasters": "مذيعو كرة سلة على كراسي متحركة",
    "canadian-football racing culture": "ثقافة سباق كرة قدم كندية",
    "volleyball racing variants": "أشكال سباق كرة طائرة",
    "volleyball leagues": "دوريات كرة طائرة",
    "rallying racing executives": "مدراء سباق راليات",
    "pesäpallo referees": "حكام بيسبالو",
    "ice skating results": "نتائج تزلج على الجليد",
    "trampolining racing seasons": "مواسم سباق جمباز قفز",
    "australian rules football racing leagues seasons": "مواسم دوريات سباق كرة قدم أسترالية",
    "modern pentathlon players": "لاعبو خماسي حديث",
    "dragon boat racing commentators": "معلقو سباق قوارب التنين",
    "poker non-profit publishers": "ناشرون غير ربحيون بوكر",
    "motorsport media": "إعلام رياضة محركات",
    "cycle racing personnel": "أفراد سباق دراجات",
    "rugby sevens racing equipment": "معدات سباق سباعيات رجبي",
    "aerobics racing variants": "أشكال سباق جمباز أيروبيكس",
    "road race culture": "ثقافة سباق دراجات على الطريق",
    "formula racing stadiums": "ملاعب سباقات فورمولا",
    "ice hockey bodies": "هيئات هوكي جليد",
    "kick boxing racing stadiums": "ملاعب سباق كيك بوكسينغ",
    "formula one songs": "أغاني فورمولا ون",
    "sepak takraw racing clubs and teams": "أندية وفرق سباق سيباك تاكرو",
    "racingxx trainers": "مدربو سباق سيارات",
    "beach soccer terminology": "مصطلحات كرة قدم شاطئية",
    "boxing trainers": "مدربو بوكسينغ",
    "canoeing films": "أفلام ركوب الكنو",
    "time trial comics": "قصص مصورة سباق دراجات ضد الساعة",
    "long jump racing films": "أفلام سباق قفز طويل",
    "dragon boat comics": "قصص مصورة سباق قوارب التنين",
    "beach handball non-playing staff": "طاقم كرة يد شاطئية غير اللاعبين",
    "pole vault racing organizations": "منظمات سباق قفز بالزانة",
    "table tennis racing fan clubs": "أندية معجبي سباق كرة طاولة",
    "kickboxing racing coaches": "مدربو سباق كيك بوكسينغ",
    "karate stadiums": "ملاعب كاراتيه",
    "bullfighting racing players": "لاعبو سباق مصارعة ثيران",
    "single skating racing owners and executives": "رؤساء تنفيذيون وملاك سباق تزلج فردي على الجليد",
    "automobile racing players": "لاعبو سباق سيارات",
    "canadian-football racing films": "أفلام سباق كرة قدم كندية",
    "rugby football racing manager history": "تاريخ مدربو سباق كرة قدم رجبي",
    "professional wrestling lists": "قوائم مصارعة محترفين",
    "underwater hockey racing songs": "أغاني سباق هوكي تحت الماء",
    "greco-roman wrestling racing managers": "مدربو سباق مصارعة يونانية رومانية",
    "cross country records and statistics": "سجلات وإحصائيات عدو ريفي",
    "bicycle motocross racing fan clubs": "أندية معجبي سباق بي ام اكس",
    "archery records and statistics": "سجلات وإحصائيات نبالة",
    "soccer racing comics": "قصص مصورة سباق كرة قدم",
    "boxing commissioners": "مفوضو بوكسينغ",
    "dragon boat coaches": "مدربو سباق قوارب التنين",
    "cross-country skiing racing manager history": "تاريخ مدربو سباق تزلج ريفي",
    "archery organizations": "منظمات نبالة",
    "trampolining personnel": "أفراد جمباز قفز",
    "track-and-field athletics rivalries": "دربيات ألعاب قوى مضمار وميدان",
    "show jumping racing leagues": "دوريات سباق قفز حواجز",
    "road race broadcasters": "مذيعو سباق دراجات على الطريق",
    "canadian-football songs": "أغاني كرة قدم كندية",
    "track-and-field athletics racing people": "أعلام سباق ألعاب قوى مضمار وميدان",
    "fencing racing footballers": "لاعبو سباق مبارزة سيف شيش",
    "boules racing non-playing staff": "طاقم سباق بوتشي غير اللاعبين",
    "snowboarding racing non-profit organizations": "منظمات غير ربحية سباق تزلج على الثلوج",
    "running non-playing staff": "طاقم ركض غير اللاعبين",
    "canadian football rivalries": "دربيات كرة قدم كندية",
    "water polo racing video games": "ألعاب فيديو سباق كرة ماء",
    "skateboarding racing competition": "منافسات سباق تزلج على اللوح",
    "long jump referees": "حكام قفز طويل",
    "bobsleigh footballers": "لاعبو زلاجة جماعية",
    "cricket racing clubs": "أندية سباق كريكت",
    "alpine skiing racing umpires": "حكام سباق تزلج على المنحدرات الثلجية",
    "canadian football leagues seasons": "مواسم دوريات كرة قدم كندية",
    "orienteering bodies": "هيئات سباق موجه",
    "single skating variants": "أشكال تزلج فردي على الجليد",
    "sepak takraw television series": "مسلسلات تلفزيونية سيباك تاكرو",
    "netball logos": "شعارات كرة شبكة",
    "board games racing rivalries": "دربيات سباق ألعاب طاولة",
    "martial arts culture": "ثقافة فنون قتالية",
    "wushu racing culture": "ثقافة سباق ووشو",
    "bullfighting stadiums": "ملاعب مصارعة ثيران",
    "snowboarding television series": "مسلسلات تلفزيونية تزلج على الثلوج",
    "dressage fan clubs": "أندية معجبي ترويض خيول",
    "dragon boat variants": "أشكال سباق قوارب التنين",
    "biathlon racing broadcasters": "مذيعو سباق بياثلون",
    "sport climbing racing trainers": "مدربو سباق تسلق",
    "artistic swimming racing footballers": "لاعبو سباق سباحة فنية",
    "sailing (sport) racing fan clubs": "أندية معجبي سباق رياضة إبحار",
    "ski jumping racing executives": "مدراء سباق قفز تزلجي",
    "sailing (sport) racing seasons": "مواسم سباق رياضة إبحار",
    "rugby union rivalries": "دربيات اتحاد رجبي",
    "artistic swimming players": "لاعبو سباحة فنية",
    "pair skating organizations": "منظمات تزلج فني على الجليد",
    "rally racing matches": "مباريات سباق رالي",
    "canoeing racing commentators": "معلقو سباق ركوب الكنو",
    "rally world competitions": "منافسات رالي عالمية",
    "bandy competitions": "منافسات باندي",
    "silat racing managers": "مدربو سباق سيلات",
    "chess racing world competitions": "منافسات سباق شطرنج عالمية",
    "greco-roman wrestling racing championships": "بطولات سباق مصارعة يونانية رومانية",
    "gaelic football executives": "مدراء كرة قدم غالية",
    "shooting sports players": "لاعبو رماية",
    "marathon running results": "نتائج سباق ماراثون",
    "association football racing awards": "جوائز سباق كرة قدم",
    "muay thai teams": "فرق موياي تاي",
    "cycling players": "لاعبو سباق دراجات هوائية",
    "ski jumping racing variants": "أشكال سباق قفز تزلجي",
    "table tennis competitions": "منافسات كرة طاولة",
    "floorball comics": "قصص مصورة كرة أرض",
    "rugby league racing video games": "ألعاب فيديو سباق دوري رجبي",
    "luge executives": "مدراء زحف ثلجي",
    "mountain bike champions": "أبطال سباق الدراجات الجبلية",
    "orienteering television series": "مسلسلات تلفزيونية سباق موجه",
    "fencing executives": "مدراء مبارزة سيف شيش",
    "cross country racing managers": "مدربو سباق عدو ريفي",
    "poker commissioners": "مفوضو بوكر",
    "ice skating tactics and skills": "مهارات تزلج على الجليد",
    "athletics lists": "قوائم ألعاب قوى",
    "rugbyunion racing awards": "جوائز سباق اتحاد رجبي",
    "pole vault racing owners": "ملاك سباق قفز بالزانة",
    "sumo media": "إعلام سومو",
    "curling racing films": "أفلام سباق كيرلنغ",
    "ice sledge hockey variants": "أشكال هوكي مزلجة على الجليد",
    "dragon boat racing non-profit organizations": "منظمات غير ربحية سباق قوارب التنين",
    "bullfighting lists": "قوائم مصارعة ثيران",
    "middle-distance running championships": "بطولات ركض مسافات متوسطة",
    "formula one racing seasons": "مواسم سباق فورمولا ون",
    "ice sledge hockey racing owners": "ملاك سباق هوكي مزلجة على الجليد",
    "short track speed skating commissioners": "مفوضو تزلج على مسار قصير",
    "croquet trainers": "مدربو كروكيت",
    "judo coaches": "مدربو جودو",
    "sailing racing umpires": "حكام سباق إبحار",
    "judo racing video games": "ألعاب فيديو سباق جودو",
    "motorboat players": "لاعبو زوارق نارية",
    "curling championships": "بطولات كيرلنغ",
    "karate manager history": "تاريخ مدربو كاراتيه",
    "gaelic football racing films": "أفلام سباق كرة قدم غالية",
    "college seasons": "مواسم كليات",
    "synchronised swimming records and statistics": "سجلات وإحصائيات سباحة متزامنة",
    "tennis racing leagues seasons": "مواسم دوريات سباق كرة مضرب",
    "aerobics competition": "منافسات جمباز أيروبيكس",
    "rowing racing managers": "مدربو سباق تجديف",
    "underwater hockey racing commissioners": "مفوضو سباق هوكي تحت الماء",
    "synchronised swimming players": "لاعبو سباحة متزامنة",
    "eventing racing managers": "مدربو سباق محاكمة خيول",
    "rugby union leagues seasons": "مواسم دوريات اتحاد رجبي",
    "shooting sports executives": "مدراء رماية",
    "freestyle wrestling seasons": "مواسم مصارعة حرة",
    "polo records and statistics": "سجلات وإحصائيات بولو",
    "hockey racing clubs and teams": "أندية وفرق سباق هوكي",
    "triathlon owners": "ملاك سباق ثلاثي",
    "diving racing non-profit publishers": "ناشرون غير ربحيون سباق غطس",
    "motorcycle racing trainers": "مدربو سباق دراجات نارية",
    "shooting players": "لاعبو رماية",
    "track-and-field athletics umpires": "حكام ألعاب قوى مضمار وميدان",
    "bobsleigh terminology": "مصطلحات زلاجة جماعية",
    "ice skating racing clubs and teams": "أندية وفرق سباق تزلج على الجليد",
    "karate racing records and statistics": "سجلات وإحصائيات سباق كاراتيه",
    "biathlon owners": "ملاك بياثلون",
    "ice skating fan clubs": "أندية معجبي تزلج على الجليد",
    "figure skating racing fan clubs": "أندية معجبي سباق تزلج فني",
    "water skiing manager history": "تاريخ مدربو تزلج على الماء",
    "futsal results": "نتائج كرة صالات",
    "wheelchair rugby league organizations": "منظمات دوري رجبي على كراسي متحركة",
    "draughts racing clubs and teams": "أندية وفرق سباق ضامة",
    "fencing songs": "أغاني مبارزة سيف شيش",
    "professional wrestling racing leagues seasons": "مواسم دوريات سباق مصارعة محترفين",
    "sailing (sport) racing clubs and teams": "أندية وفرق سباق رياضة إبحار",
    "sailing (sport) racing songs": "أغاني سباق رياضة إبحار",
    "sailing (sport) racing broadcasters": "مذيعو سباق رياضة إبحار",
    "sports players": "لاعبو رياضية",
    "ski jumping racing media": "إعلام سباق قفز تزلجي",
    "wheelchair beach handball terminology": "مصطلحات كرة يد شاطئية على كراسي متحركة",
    "wheelchair beach handball trainers": "مدربو كرة يد شاطئية على كراسي متحركة",
    "motor racing manager": "مدربو سباق محركات",
    "kurash racing fan clubs": "أندية معجبي سباق كوراش",
    "gymnastics racing organizations": "منظمات سباق جمباز",
    "boxing managers": "مدربو بوكسينغ",
    "aquatics racing managers": "مدربو سباق رياضات مائية",
    "bmx bodies": "هيئات سباق بي إم إكس",
    "bowls racing stadiums": "ملاعب سباق بولينج",
    "sumo racing terminology": "مصطلحات سباق سومو",
    "mixed martial arts music": "موسيقى فنون قتال مختلطة",
    "pair skating players": "لاعبو تزلج فني على الجليد",
    "polo trainers": "مدربو بولو",
    "sambo music": "موسيقى سامبو",
    "gaelic football racing rivalries": "دربيات سباق كرة قدم غالية",
    "bowling awards": "جوائز بولينج",
    "canoeing footballers": "لاعبو ركوب الكنو",
    "darts racing variants": "أشكال سباق سهام مريشة",
    "badminton fan clubs": "أندية معجبي تنس ريشة",
    "racingxx managers": "مدربو سباق سيارات",
    "artistic gymnastics racing coaches": "مدربو سباق جمباز فني",
    "inline hockey results": "نتائج هوكي مضمن",
    "high jump racing terminology": "مصطلحات سباق قفز عالي",
    "artistic gymnastics managers": "مدربو جمباز فني",
    "ice hockey umpires": "حكام هوكي جليد",
    "racquetball clubs": "أندية كرة الراح",
    "equestrianism non-playing staff": "طاقم فروسية غير اللاعبين",
    "hammer throw non-playing staff": "طاقم رمي مطرقة غير اللاعبين",
    "snowboarding manager history": "تاريخ مدربو تزلج على الثلوج",
    "cross country trainers": "مدربو عدو ريفي",
    "wrestling video games": "ألعاب فيديو مصارعة",
    "australian rules football racing clubs and teams": "أندية وفرق سباق كرة قدم أسترالية",
    "motorsports leagues seasons": "مواسم دوريات رياضة محركات",
    "badminton coaches": "مدربو تنس ريشة",
    "skeleton commissioners": "مفوضو زلاجات صدرية",
    "show jumping leagues seasons": "مواسم دوريات قفز حواجز",
    "draughts non-profit organizations": "منظمات غير ربحية ضامة",
    "ice sledge hockey comics": "قصص مصورة هوكي مزلجة على الجليد",
    "formula one racing players": "لاعبو سباق فورمولا ون",
    "single skating racing equipment": "معدات سباق تزلج فردي على الجليد",
    "chess players": "لاعبو شطرنج",
    "aquatics racing terminology": "مصطلحات سباق رياضات مائية",
    "wheelchair basketball people": "أعلام كرة سلة على كراسي متحركة",
    "rowing fan clubs": "أندية معجبي تجديف",
    "motorsports racing competition": "منافسات سباق رياضة محركات",
    "college racing manager history": "تاريخ مدربو سباق كليات",
    "athletics racing footballers": "لاعبو سباق ألعاب قوى",
    "wheelchair fencing non-playing staff": "طاقم مبارزة سيف شيش على كراسي متحركة غير اللاعبين",
    "formula e racing media": "إعلام سباق فورمولا إي",
    "softball players": "لاعبو كرة لينة",
    "motorsports racing matches": "مباريات سباق رياضة محركات",
    "fencing commentators": "معلقو مبارزة سيف شيش",
    "australian rules football racing leagues": "دوريات سباق كرة قدم أسترالية",
    "track-and-field athletics personnel": "أفراد ألعاب قوى مضمار وميدان",
    "sailing (sport) racing governing bodies": "هيئات تنظيم سباق رياضة إبحار",
    "formula one racing executives": "مدراء سباق فورمولا ون",
    "discus throw racing results": "نتائج سباق رمي قرص",
    "equestrian video games": "ألعاب فيديو فروسية",
    "basque pelota racing players": "لاعبو سباق كرة باسك",
    "shooting sports personnel": "أفراد رماية",
    "ice sledge hockey equipment": "معدات هوكي مزلجة على الجليد",
    "track cycling awards": "جوائز سباق الدراجات على المضمار",
    "skateboarding racing terminology": "مصطلحات سباق تزلج على اللوح",
    "floorball films": "أفلام كرة أرض",
    "silat racing non-profit publishers": "ناشرون غير ربحيون سباق سيلات",
    "go personnel": "أفراد غو",
    "fencing racing awards": "جوائز سباق مبارزة سيف شيش",
    "draughts stadiums": "ملاعب ضامة",
    "silat broadcasters": "مذيعو سيلات",
    "hurling organizations": "منظمات قذف",
    "biathlon racing organizations": "منظمات سباق بياثلون",
    "go non-profit organizations": "منظمات غير ربحية غو",
    "rugby sevens non-playing staff": "طاقم سباعيات رجبي غير اللاعبين",
    "inline hockey terminology": "مصطلحات هوكي مضمن",
    "cycling road race records and statistics": "سجلات وإحصائيات سباق دراجات على الطريق",
    "sport climbing leagues seasons": "مواسم دوريات تسلق",
    "sport climbing owners and executives": "رؤساء تنفيذيون وملاك تسلق",
    "boccia racing lists": "قوائم سباق بوتشيا",
    "water skiing non-profit organizations": "منظمات غير ربحية تزلج على الماء",
    "long-distance running video games": "ألعاب فيديو ركض مسافات طويلة",
    "triple jump leagues": "دوريات قفز ثلاثي",
    "racquetball leagues seasons": "مواسم دوريات كرة الراح",
    "shooting sport racing competition": "منافسات سباق رماية",
    "ice sledge hockey racing television series": "مسلسلات تلفزيونية سباق هوكي مزلجة على الجليد",
    "judo stadiums": "ملاعب جودو",
    "equestrianism racing governing bodies": "هيئات تنظيم سباق فروسية",
    "track-and-field athletics racing trainers": "مدربو سباق ألعاب قوى مضمار وميدان",
    "bowling manager history": "تاريخ مدربو بولينج",
    "surfing racing seasons": "مواسم سباق ركمجة",
    "underwater hockey racing television series": "مسلسلات تلفزيونية سباق هوكي تحت الماء",
    "alpine skiing managers": "مدربو تزلج على المنحدرات الثلجية",
    "shooting comics": "قصص مصورة رماية",
    "sailing records and statistics": "سجلات وإحصائيات إبحار",
    "gymnastics racing culture": "ثقافة سباق جمباز",
    "track-and-field athletics equipment": "معدات ألعاب قوى مضمار وميدان",
    "pencak silat racing clubs": "أندية سباق بنكات سيلات",
    "ski flying media": "إعلام تزلج طائر",
    "pole vault awards": "جوائز قفز بالزانة",
    "wheelchair beach handball owners": "ملاك كرة يد شاطئية على كراسي متحركة",
    "rifle shooting racing records and statistics": "سجلات وإحصائيات سباق رماية بندقية",
    "show jumping logos": "شعارات قفز حواجز",
    "wushu executives": "مدراء ووشو",
    "pair skating world competitions": "منافسات تزلج فني على الجليد عالمية",
    "professional wrestling racing rivalries": "دربيات سباق مصارعة محترفين",
    "motor players": "لاعبو محركات",
    "cyclo-cross racing umpires": "حكام سباق سيكلو كروس",
    "bmx commentators": "معلقو سباق بي إم إكس",
    "weightlifting racing clubs and teams": "أندية وفرق سباق رفع أثقال",
    "canoe sprint culture": "ثقافة سباق قوارب",
    "ball hockey media": "إعلام هوكي كرة",
    "canoeing and kayaking racing umpires": "حكام سباق كانو-كاياك",
    "surfing variants": "أشكال ركمجة",
    "discus throw racing people": "أعلام سباق رمي قرص",
    "kurash teams": "فرق كوراش",
    "speed skiing logos": "شعارات تزلج سريع",
    "ice skating racing culture": "ثقافة سباق تزلج على الجليد",
    "canoeing people": "أعلام ركوب الكنو",
    "relay race manager": "مدربو سباق تتابع",
    "track-and-field athletics racing non-playing staff": "طاقم سباق ألعاب قوى مضمار وميدان غير اللاعبين",
    "shooting non-profit publishers": "ناشرون غير ربحيون رماية",
    "show jumping racing media": "إعلام سباق قفز حواجز",
    "croquet culture": "ثقافة كروكيت",
    "figure skating racing trainers": "مدربو سباق تزلج فني",
    "rowing clubs": "أندية تجديف",
    "board games songs": "أغاني ألعاب طاولة",
    "field hockey racing trainers": "مدربو سباق هوكي ميدان",
    "pole vault tactics and skills": "مهارات قفز بالزانة",
    "submission wrestling media": "إعلام مصارعة خضوع",
    "equestrian media": "إعلام فروسية",
    "college music": "موسيقى كليات",
    "squash racing bodies": "هيئات سباق اسكواش",
    "waterskiing racing seasons": "مواسم سباق تزلج على الماء",
    "sumo racing variants": "أشكال سباق سومو",
    "rugbyunion umpires": "حكام اتحاد رجبي",
    "synchronised swimming racing non-profit publishers": "ناشرون غير ربحيون سباق سباحة متزامنة",
    "handball clubs and teams": "أندية وفرق كرة يد",
    "ski flying racing commentators": "معلقو سباق تزلج طائر",
    "curling racing championships": "بطولات سباق كيرلنغ",
    "gridiron football racing films": "أفلام سباق كرة قدم أمريكية شمالية",
    "lacrosse awards": "جوائز لاكروس",
    "pencak silat people": "أعلام بنكات سيلات",
    "sledge hockey racing equipment": "معدات سباق هوكي مزلجة",
    "climbing racing music": "موسيقى سباق تسلق",
    "goalball people": "أعلام كرة هدف",
    "bullfighting racing films": "أفلام سباق مصارعة ثيران",
    "skeleton racing trainers": "مدربو سباق زلاجات صدرية",
    "bouldering video games": "ألعاب فيديو بولدرنق",
    "rally raid racing fan clubs": "أندية معجبي سباق رالي رايد",
    "badminton clubs": "أندية تنس ريشة",
    "taekwondo racing clubs and teams": "أندية وفرق سباق تايكوندو",
    "rugbyunion leagues seasons": "مواسم دوريات اتحاد رجبي",
    "bowling non-profit organizations": "منظمات غير ربحية بولينج",
    "roller skating racing seasons": "مواسم سباق تزلج بالعجلات",
    "pesäpallo television series": "مسلسلات تلفزيونية بيسبالو",
    "lacrosse rivalries": "دربيات لاكروس",
    "waterskiing stadiums": "ملاعب تزلج على الماء",
    "bullfighting racing rivalries": "دربيات سباق مصارعة ثيران",
    "archery clubs": "أندية نبالة",
    "shooting sport manager": "مدربو رماية",
    "powerlifting manager": "مدربو رياضة قوة",
    "board games leagues": "دوريات ألعاب طاولة",
    "sumo films": "أفلام سومو",
    "cross-country skiing players": "لاعبو تزلج ريفي",
    "underwater hockey tactics and skills": "مهارات هوكي تحت الماء",
    "american football culture": "ثقافة كرة قدم أمريكية",
    "acrobatic gymnastics stadiums": "ملاعب جمباز اكروباتيكي",
    "synchronized swimming organizations": "منظمات سباحة متزامنة",
    "chinese martial arts comics": "قصص مصورة فنون قتالية صينية",
    "sprinting racing leagues seasons": "مواسم دوريات سباق جري سريع",
    "speed skating racing lists": "قوائم سباق تزلج سريع",
    "professional wrestling seasons": "مواسم مصارعة محترفين",
    "kabaddi terminology": "مصطلحات كابادي",
    "modern pentathlon television series": "مسلسلات تلفزيونية خماسي حديث",
    "speed skating fan clubs": "أندية معجبي تزلج سريع",
    "american football clubs": "أندية كرة قدم أمريكية",
    "snooker competitions": "منافسات سنوكر",
    "go racing music": "موسيقى سباق غو",
    "ice dancing television series": "مسلسلات تلفزيونية رقص على جليد",
    "long jump rivalries": "دربيات قفز طويل",
    "wheelchair curling rivalries": "دربيات كيرلنغ على كراسي متحركة",
    "canadian-football racing non-profit publishers": "ناشرون غير ربحيون سباق كرة قدم كندية",
    "badminton racing competition": "منافسات سباق تنس ريشة",
    "tennis people": "أعلام كرة مضرب",
    "canoeing and kayaking video games": "ألعاب فيديو كانو-كاياك",
    "formula one governing bodies": "هيئات تنظيم فورمولا ون",
    "soft tennis manager history": "تاريخ مدربو كرة مضرب لينة",
    "soccer coaches": "مدربو كرة قدم",
    "curling racing music": "موسيقى سباق كيرلنغ",
    "wheelchair beach handball world competitions": "منافسات كرة يد شاطئية على كراسي متحركة عالمية",
    "polo rivalries": "دربيات بولو",
    "rugbyunion broadcasters": "مذيعو اتحاد رجبي",
    "bouldering racing matches": "مباريات سباق بولدرنق",
    "motor stadiums": "ملاعب محركات",
    "jujutsu world competitions": "منافسات جوجوتسو عالمية",
    "diving equipment": "معدات غطس",
    "aerobics non-profit publishers": "ناشرون غير ربحيون جمباز أيروبيكس",
    "chess racing television series": "مسلسلات تلفزيونية سباق شطرنج",
    "polo racing tactics and skills": "مهارات سباق بولو",
    "sailing (sport) owners": "ملاك رياضة إبحار",
    "basque pelota racing managers": "مدربو سباق كرة باسك",
    "roller hockey (quad) racing competition": "منافسات سباق هوكي دحرجة",
    "soft tennis managers": "مدربو كرة مضرب لينة",
    "bobsleigh racing fan clubs": "أندية معجبي سباق زلاجة جماعية",
    "sledge hockey racing commissioners": "مفوضو سباق هوكي مزلجة",
    "mixed martial arts racing players": "لاعبو سباق فنون قتال مختلطة",
    "shooting sport organizations": "منظمات رماية",
    "polo racing competition": "منافسات سباق بولو",
    "sepak takraw racing tactics and skills": "مهارات سباق سيباك تاكرو",
    "badminton music": "موسيقى تنس ريشة",
    "speed skiing footballers": "لاعبو تزلج سريع",
    "sledge hockey racing songs": "أغاني سباق هوكي مزلجة",
    "surfing bodies": "هيئات ركمجة",
    "rifle shooting racing umpires": "حكام سباق رماية بندقية",
    "rugby football racing world competitions": "منافسات سباق كرة قدم رجبي عالمية",
    "american-football racing fan clubs": "أندية معجبي سباق كرة قدم أمريكية",
    "climbing coaches": "مدربو تسلق",
    "ju-jitsu racing footballers": "لاعبو سباق جوجوتسو",
    "swimming racing leagues": "دوريات سباق سباحة",
    "climbing songs": "أغاني تسلق",
    "hurling governing bodies": "هيئات تنظيم قذف",
    "triathlon television series": "مسلسلات تلفزيونية سباق ثلاثي",
    "draughts championships": "بطولات ضامة",
    "australian rules football clubs and teams": "أندية وفرق كرة قدم أسترالية",
    "american-football non-profit publishers": "ناشرون غير ربحيون كرة قدم أمريكية",
    "skiing television series": "مسلسلات تلفزيونية تزلج",
    "wheelchair curling results": "نتائج كيرلنغ على كراسي متحركة",
    "tennis results": "نتائج كرة مضرب",
    "formula one racing non-profit publishers": "ناشرون غير ربحيون سباق فورمولا ون",
    "skeleton racing terminology": "مصطلحات سباق زلاجات صدرية",
    "goalball equipment": "معدات كرة هدف",
    "muay thai owners": "ملاك موياي تاي",
    "gridiron football leagues seasons": "مواسم دوريات كرة قدم أمريكية شمالية",
    "motocross terminology": "مصطلحات موتو كروس",
    "volleyball lists": "قوائم كرة طائرة",
    "boxing racing governing bodies": "هيئات تنظيم سباق بوكسينغ",
    "gridiron football racing results": "نتائج سباق كرة قدم أمريكية شمالية",
    "acrobatic gymnastics racing fan clubs": "أندية معجبي سباق جمباز اكروباتيكي",
    "rally raid racing umpires": "حكام سباق رالي رايد",
    "wheelchair curling footballers": "لاعبو كيرلنغ على كراسي متحركة",
    "nordic combined rivalries": "دربيات تزلج نوردي مزدوج",
    "time trial world competitions": "منافسات سباق دراجات ضد الساعة عالمية",
    "pentathlon racing matches": "مباريات سباق خماسي",
    "poker films": "أفلام بوكر",
    "draughts racing records and statistics": "سجلات وإحصائيات سباق ضامة",
    "middle-distance running racing logos": "شعارات سباق ركض مسافات متوسطة",
    "cue sports variants": "أشكال بلياردو",
    "surfing players": "لاعبو ركمجة",
    "sport climbing racing personnel": "أفراد سباق تسلق",
    "motorboat lists": "قوائم زوارق نارية",
    "aquatic sports video games": "ألعاب فيديو رياضات مائية",
    "gymnastics records and statistics": "سجلات وإحصائيات جمباز",
    "racquets video games": "ألعاب فيديو لعبة الراح",
    "football racing stadiums": "ملاعب سباق كرة قدم",
    "esports racing manager history": "تاريخ مدربو سباق رياضة إلكترونية",
    "rugby racing terminology": "مصطلحات سباق رجبي",
    "motor umpires": "حكام محركات",
    "sepak takraw racing world competitions": "منافسات سباق سيباك تاكرو عالمية",
    "diving racing seasons": "مواسم سباق غطس",
    "skeleton racing coaches": "مدربو سباق زلاجات صدرية",
    "american football fan clubs": "أندية معجبي كرة قدم أمريكية",
    "shooting sport racing players": "لاعبو سباق رماية",
    "croquet owners and executives": "رؤساء تنفيذيون وملاك كروكيت",
    "aquatics racing championships": "بطولات سباق رياضات مائية",
    "sailing racing video games": "ألعاب فيديو سباق إبحار",
    "tennis racing television series": "مسلسلات تلفزيونية سباق كرة مضرب",
    "wheelchair curling world competitions": "منافسات كيرلنغ على كراسي متحركة عالمية",
    "cue sports players": "لاعبو بلياردو",
    "martial arts umpires": "حكام فنون قتالية",
    "ball hockey lists": "قوائم هوكي كرة",
    "wheelchair rugby league stadiums": "ملاعب دوري رجبي على كراسي متحركة",
    "motorsport racing commissioners": "مفوضو سباق رياضة محركات",
    "cricket racing executives": "مدراء سباق كريكت",
    "motocross racing manager history": "تاريخ مدربو سباق موتو كروس",
    "rifle shooting racing films": "أفلام سباق رماية بندقية",
    "muay thai racing clubs": "أندية سباق موياي تاي",
    "pair skating personnel": "أفراد تزلج فني على الجليد",
    "boules organizations": "منظمات بوتشي",
    "shooting chairmen and investors": "رؤساء ومسيرو رماية",
    "professional wrestling racing players": "لاعبو سباق مصارعة محترفين",
    "shot put players": "لاعبو دفع ثقل",
    "pair skating racing music": "موسيقى سباق تزلج فني على الجليد",
    "automobile racing variants": "أشكال سباق سيارات",
    "rugbyunion racing films": "أفلام سباق اتحاد رجبي",
    "croquet racing leagues": "دوريات سباق كروكيت",
    "gridiron football racing fan clubs": "أندية معجبي سباق كرة قدم أمريكية شمالية",
    "boxing world competitions": "منافسات بوكسينغ عالمية",
    "rugby racing tactics and skills": "مهارات سباق رجبي",
    "polo video games": "ألعاب فيديو بولو",
    "cross-country skiing racing films": "أفلام سباق تزلج ريفي",
    "ju-jitsu trainers": "مدربو جوجوتسو",
    "rally racing variants": "أشكال سباق رالي",
    "badminton commentators": "معلقو تنس ريشة",
    "water skiing racing footballers": "لاعبو سباق تزلج على الماء",
    "wheelchair fencing seasons": "مواسم مبارزة سيف شيش على كراسي متحركة",
    "motorboat results": "نتائج زوارق نارية",
    "track-and-field athletics culture": "ثقافة ألعاب قوى مضمار وميدان",
    "darts songs": "أغاني سهام مريشة",
    "football racing films": "أفلام سباق كرة قدم",
    "pole vault racing competition": "منافسات سباق قفز بالزانة",
    "archery racing footballers": "لاعبو سباق نبالة",
    "mountain bike seasons": "مواسم سباق الدراجات الجبلية",
    "bmx racing players": "لاعبو سباق بي إم إكس",
    "soccer racing executives": "مدراء سباق كرة قدم",
    "beach soccer organizations": "منظمات كرة قدم شاطئية",
    "taekwondo racing bodies": "هيئات سباق تايكوندو",
    "bouldering logos": "شعارات بولدرنق",
    "boccia competition": "منافسات بوتشيا",
    "silat stadiums": "ملاعب سيلات",
    "rallying non-profit organizations": "منظمات غير ربحية راليات",
    "track-and-field athletics songs": "أغاني ألعاب قوى مضمار وميدان",
    "formula racing players": "لاعبو سباقات فورمولا",
    "beach soccer racing video games": "ألعاب فيديو سباق كرة قدم شاطئية",
    "speed skating players": "لاعبو تزلج سريع",
    "high school racing logos": "شعارات سباق مدارس ثانوية",
    "cycle trainers": "مدربو دراجات",
    "college television series": "مسلسلات تلفزيونية كليات",
    "basque pelota racing executives": "مدراء سباق كرة باسك",
    "soccer stadiums": "ملاعب كرة قدم",
    "college racing umpires": "حكام سباق كليات",
    "ice dancing commissioners": "مفوضو رقص على جليد",
    "eventing referees": "حكام محاكمة خيول",
    "powerlifting racing records and statistics": "سجلات وإحصائيات سباق رياضة قوة",
    "submission wrestling broadcasters": "مذيعو مصارعة خضوع",
    "sport climbing racing results": "نتائج سباق تسلق",
    "rallying governing bodies": "هيئات تنظيم راليات",
    "kick boxing lists": "قوائم كيك بوكسينغ",
    "lacrosse clubs and teams": "أندية وفرق لاكروس",
    "gridiron football racing logos": "شعارات سباق كرة قدم أمريكية شمالية",
    "figure skating racing equipment": "معدات سباق تزلج فني",
    "rugby football comics": "قصص مصورة كرة قدم رجبي",
    "pentathlon racing competition": "منافسات سباق خماسي",
    "trampolining songs": "أغاني جمباز قفز",
    "formula e players": "لاعبو فورمولا إي",
    "ball hockey racing tactics and skills": "مهارات سباق هوكي كرة",
    "greco-roman wrestling personnel": "أفراد مصارعة يونانية رومانية",
    "cycle race competition": "منافسات سباق دراجات",
    "xiangqi racing culture": "ثقافة سباق شطرنج صيني",
    "canoe sprint commentators": "معلقو سباق قوارب",
    "esports racing manager": "مدربو سباق رياضة إلكترونية",
    "nordic combined racing lists": "قوائم سباق تزلج نوردي مزدوج",
    "ski jumping rivalries": "دربيات قفز تزلجي",
    "go culture": "ثقافة غو",
    "canoeing championships": "بطولات ركوب الكنو",
    "field hockey leagues seasons": "مواسم دوريات هوكي ميدان",
    "pencak silat racing music": "موسيقى سباق بنكات سيلات",
    "wheelchair beach handball governing bodies": "هيئات تنظيم كرة يد شاطئية على كراسي متحركة",
    "long-distance running non-playing staff": "طاقم ركض مسافات طويلة غير اللاعبين",
    "synchronised swimming racing songs": "أغاني سباق سباحة متزامنة",
    "show jumping racing logos": "شعارات سباق قفز حواجز",
    "basque pelota racing lists": "قوائم سباق كرة باسك",
    "formula racing logos": "شعارات سباقات فورمولا",
    "badminton racing executives": "مدراء سباق تنس ريشة",
    "association football films": "أفلام كرة قدم",
    "diving trainers": "مدربو غطس",
    "ju-jitsu leagues seasons": "مواسم دوريات جوجوتسو",
    "aerobics films": "أفلام جمباز أيروبيكس",
    "pair skating racing players": "لاعبو سباق تزلج فني على الجليد",
    "baseball racing broadcasters": "مذيعو سباق كرة قاعدة",
    "skateboarding people": "أعلام تزلج على اللوح",
    "skeleton racing players": "لاعبو سباق زلاجات صدرية",
    "rugby governing bodies": "هيئات تنظيم رجبي",
    "auto racing fan clubs": "أندية معجبي سباق سيارات",
    "athletics personnel": "أفراد ألعاب قوى",
    "squash seasons": "مواسم اسكواش",
    "hockey equipment": "معدات هوكي",
    "wheelchair handball referees": "حكام كرة يد على كراسي متحركة",
    "formula e racing players": "لاعبو سباق فورمولا إي",
    "mountain bike racing competitions": "منافسات سباق الدراجات الجبلية",
    "racewalking fan clubs": "أندية معجبي سباق جري",
    "cycle variants": "أشكال دراجات",
    "greco-roman wrestling racing commentators": "معلقو سباق مصارعة يونانية رومانية",
    "sprinting trainers": "مدربو جري سريع",
    "rally raid media": "إعلام رالي رايد",
    "rowing lists": "قوائم تجديف",
    "pole vault racing rivalries": "دربيات سباق قفز بالزانة",
    "taekwondo racing lists": "قوائم سباق تايكوندو",
    "ice dancing racing leagues": "دوريات سباق رقص على جليد",
    "biathlon racing clubs": "أندية سباق بياثلون",
    "lacrosse media": "إعلام لاكروس",
    "trampolining matches": "مباريات جمباز قفز",
    "bouldering racing seasons": "مواسم سباق بولدرنق",
    "racquets music": "موسيقى لعبة الراح",
    "shooting sport racing organizations": "منظمات سباق رماية",
    "long-distance running referees": "حكام ركض مسافات طويلة",
    "dragon boat racing manager history": "تاريخ مدربو سباق قوارب التنين",
    "karate governing bodies": "هيئات تنظيم كاراتيه",
    "hockey commissioners": "مفوضو هوكي",
    "table tennis fan clubs": "أندية معجبي كرة طاولة",
    "golf organizations": "منظمات غولف",
    "association football logos": "شعارات كرة قدم",
    "synchronized swimming songs": "أغاني سباحة متزامنة",
    "single skating video games": "ألعاب فيديو تزلج فردي على الجليد",
    "association football racing lists": "قوائم سباق كرة قدم",
    "korfball racing coaches": "مدربو سباق كورفبال",
    "karate championships": "بطولات كاراتيه",
    "wushu television series": "مسلسلات تلفزيونية ووشو",
    "cricket owners and executives": "رؤساء تنفيذيون وملاك كريكت",
    "acrobatic gymnastics racing manager history": "تاريخ مدربو سباق جمباز اكروباتيكي",
    "formula e music": "موسيقى فورمولا إي",
    "cricket racing referees": "حكام سباق كريكت",
    "association football media": "إعلام كرة قدم",
    "shooting results": "نتائج رماية",
    "bicycle motocross manager history": "تاريخ مدربو بي ام اكس",
    "ski flying executives": "مدراء تزلج طائر",
    "bmx racing culture": "ثقافة سباق بي إم إكس",
    "polo owners and executives": "رؤساء تنفيذيون وملاك بولو",
    "gaelic football songs": "أغاني كرة قدم غالية",
    "javelin throw racing broadcasters": "مذيعو سباق رمي رمح",
    "american football commissioners": "مفوضو كرة قدم أمريكية",
    "pair skating television series": "مسلسلات تلفزيونية تزلج فني على الجليد",
    "shooting umpires": "حكام رماية",
    "weightlifting racing commissioners": "مفوضو سباق رفع أثقال",
    "formula one racing competition": "منافسات سباق فورمولا ون",
    "dragon boat awards": "جوائز سباق قوارب التنين",
    "college racing executives": "مدراء سباق كليات",
    "motocross racing leagues": "دوريات سباق موتو كروس",
    "kickboxing racing governing bodies": "هيئات تنظيم سباق كيك بوكسينغ",
    "badminton broadcasters": "مذيعو تنس ريشة",
    "sumo racing fan clubs": "أندية معجبي سباق سومو",
    "formula one manager": "مدربو فورمولا ون",
    "badminton songs": "أغاني تنس ريشة",
    "lawn bowls racing seasons": "مواسم سباق بولينغ عشبي",
    "swimming comics": "قصص مصورة سباحة",
    "wheelchair handball championships": "بطولات كرة يد على كراسي متحركة",
    "triple jump racing logos": "شعارات سباق قفز ثلاثي",
    "wheelchair basketball logos": "شعارات كرة سلة على كراسي متحركة",
    "ice dancing racing culture": "ثقافة سباق رقص على جليد",
    "rifle shooting racing trainers": "مدربو سباق رماية بندقية",
    "cricket trainers": "مدربو كريكت",
    "roller hockey (quad) non-profit organizations": "منظمات غير ربحية هوكي دحرجة",
    "badminton racing owners": "ملاك سباق تنس ريشة",
    "skeleton owners and executives": "رؤساء تنفيذيون وملاك زلاجات صدرية",
    "pair skating racing lists": "قوائم سباق تزلج فني على الجليد",
    "track cycling comics": "قصص مصورة سباق الدراجات على المضمار",
    "swimming racing video games": "ألعاب فيديو سباق سباحة",
    "ju-jitsu matches": "مباريات جوجوتسو",
    "beach volleyball rivalries": "دربيات كرة طائرة شاطئية",
    "sport climbing racing manager": "مدربو سباق تسلق",
    "wushu personnel": "أفراد ووشو",
    "relay race stadiums": "ملاعب سباق تتابع",
    "pole vault racing broadcasters": "مذيعو سباق قفز بالزانة",
    "volleyball fan clubs": "أندية معجبي كرة طائرة",
    "formula one racing world competitions": "منافسات سباق فورمولا ون عالمية",
    "silat leagues": "دوريات سيلات",
    "rugby football racing coaches": "مدربو سباق كرة قدم رجبي",
    "kickboxing racing players": "لاعبو سباق كيك بوكسينغ",
    "lacrosse racing players": "لاعبو سباق لاكروس",
    "basque pelota racing leagues seasons": "مواسم دوريات سباق كرة باسك",
    "modern pentathlon racing coaches": "مدربو سباق خماسي حديث",
    "basque pelota racing non-profit publishers": "ناشرون غير ربحيون سباق كرة باسك",
    "sledge hockey racing championships": "بطولات سباق هوكي مزلجة",
    "field hockey coaches": "مدربو هوكي ميدان",
    "shot put manager": "مدربو دفع ثقل",
    "middle-distance running racing non-profit publishers": "ناشرون غير ربحيون سباق ركض مسافات متوسطة",
    "long-distance running racing television series": "مسلسلات تلفزيونية سباق ركض مسافات طويلة",
    "canoeing executives": "مدراء ركوب الكنو",
    "nordic combined racing clubs and teams": "أندية وفرق سباق تزلج نوردي مزدوج",
    "powerlifting culture": "ثقافة رياضة قوة",
    "mountain bike commentators": "معلقو سباق الدراجات الجبلية",
    "long jump people": "أعلام قفز طويل",
    "show jumping racing songs": "أغاني سباق قفز حواجز",
    "goalball racing commissioners": "مفوضو سباق كرة هدف",
    "sledge hockey racing tactics and skills": "مهارات سباق هوكي مزلجة",
    "high jump racing manager history": "تاريخ مدربو سباق قفز عالي",
    "boules racing lists": "قوائم سباق بوتشي",
    "basketball non-profit organizations": "منظمات غير ربحية كرة سلة",
    "underwater hockey racing leagues": "دوريات سباق هوكي تحت الماء",
    "baseball racing footballers": "لاعبو سباق كرة قاعدة",
    "cross-country skiing songs": "أغاني تزلج ريفي",
    "figure skating racing clubs and teams": "أندية وفرق سباق تزلج فني",
    "yacht racing umpires": "حكام سباقات يخوت",
    "freestyle wrestling racing comics": "قصص مصورة سباق مصارعة حرة",
    "boccia racing managers": "مدربو سباق بوتشيا",
    "pesäpallo racing manager": "مدربو سباق بيسبالو",
    "field hockey racing commissioners": "مفوضو سباق هوكي ميدان",
    "boxing chairmen and investors": "رؤساء ومسيرو بوكسينغ",
    "basketball chairmen and investors": "رؤساء ومسيرو كرة سلة",
    "water polo racing chairmen and investors": "رؤساء ومسيرو سباق كرة ماء",
    "curling racing chairmen and investors": "رؤساء ومسيرو سباق كيرلنغ",
    "marathon running chairmen and investors": "رؤساء ومسيرو سباق ماراثون",
    "beach volleyball chairmen and investors": "رؤساء ومسيرو كرة طائرة شاطئية",
    "chinese martial arts racing chairmen and investors": "رؤساء ومسيرو سباق فنون قتالية صينية",
    "bodybuilding racing chairmen and investors": "رؤساء ومسيرو سباق كمال أجسام",
    "go racing chairmen and investors": "رؤساء ومسيرو سباق غو",
    "high jump racing chairmen and investors": "رؤساء ومسيرو سباق قفز عالي",
    "eventing chairmen and investors": "رؤساء ومسيرو محاكمة خيول",
    "submission wrestling chairmen and investors": "رؤساء ومسيرو مصارعة خضوع",
    "croquet chairmen and investors": "رؤساء ومسيرو كروكيت",
    "rowing chairmen and investors": "رؤساء ومسيرو تجديف",
    "roller skating racing chairmen and investors": "رؤساء ومسيرو سباق تزلج بالعجلات",
    "speed skiing racing chairmen and investors": "رؤساء ومسيرو سباق تزلج سريع",
    "polo racing chairmen and investors": "رؤساء ومسيرو سباق بولو",
    "soccer chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "single skating racing chairmen and investors": "رؤساء ومسيرو سباق تزلج فردي على الجليد",
    "association football chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "football chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "rugby league chairmen and investors": "رؤساء ومسيرو دوري الرجبي",
    "rugby union chairmen and investors": "رؤساء ومسيرو اتحاد الرجبي",
    "roller skating champions": "أبطال التزلج بالعجلات",
    "cross country running racing champions": "أبطال سباق العدو الريفي",
    "basketball champions": "أبطال كرة السلة",
    "archery racing champions": "أبطال سباق النبالة",
    "skateboarding racing champions": "أبطال سباق التزلج على اللوح",
    "basque pelota champions": "أبطال كرة الباسك",
    "fencing racing champions": "أبطال سباق مبارزة سيف الشيش",
    "shooting champions": "أبطال الرماية",
    "nordic combined racing champions": "أبطال سباق التزلج النوردي المزدوج",
    "triathlon champions": "أبطال السباق الثلاثي",
    "kick boxing racing champions": "أبطال سباق الكيك بوكسينغ",
    "speed skating champions": "أبطال التزلج السريع",
    "karate champions": "أبطال الكاراتيه",
    "wheelchair fencing champions": "أبطال مبارزة سيف الشيش على الكراسي المتحركة",
}

data_3 = {
    "boxing chairmen and investors": "رؤساء ومسيرو بوكسينغ",
    "basketball chairmen and investors": "رؤساء ومسيرو كرة سلة",
    "water polo racing chairmen and investors": "رؤساء ومسيرو سباق كرة ماء",
    "curling racing chairmen and investors": "رؤساء ومسيرو سباق كيرلنغ",
    "marathon running chairmen and investors": "رؤساء ومسيرو سباق ماراثون",
    "beach volleyball chairmen and investors": "رؤساء ومسيرو كرة طائرة شاطئية",
    "chinese martial arts racing chairmen and investors": "رؤساء ومسيرو سباق فنون قتالية صينية",
    "bodybuilding racing chairmen and investors": "رؤساء ومسيرو سباق كمال أجسام",
    "go racing chairmen and investors": "رؤساء ومسيرو سباق غو",
    "high jump racing chairmen and investors": "رؤساء ومسيرو سباق قفز عالي",
    "eventing chairmen and investors": "رؤساء ومسيرو محاكمة خيول",
    "submission wrestling chairmen and investors": "رؤساء ومسيرو مصارعة خضوع",
    "croquet chairmen and investors": "رؤساء ومسيرو كروكيت",
    "rowing chairmen and investors": "رؤساء ومسيرو تجديف",
    "roller skating racing chairmen and investors": "رؤساء ومسيرو سباق تزلج بالعجلات",
    "speed skiing racing chairmen and investors": "رؤساء ومسيرو سباق تزلج سريع",
    "polo racing chairmen and investors": "رؤساء ومسيرو سباق بولو",
    "soccer chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "single skating racing chairmen and investors": "رؤساء ومسيرو سباق تزلج فردي على الجليد",
    "association football chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "football chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "rugby league chairmen and investors": "رؤساء ومسيرو دوري الرجبي",
    "rugby union chairmen and investors": "رؤساء ومسيرو اتحاد الرجبي",
    # "rugby league chairmen and investors": "رؤساء ومسيرو دوري رجبي",
    # "rugby union chairmen and investors": "رؤساء ومسيرو اتحاد رجبي",
    "roller skating champions": "أبطال التزلج بالعجلات",
    "cross country running racing champions": "أبطال سباق العدو الريفي",
    "basketball champions": "أبطال كرة السلة",
    "archery racing champions": "أبطال سباق النبالة",
    "skateboarding racing champions": "أبطال سباق التزلج على اللوح",
    "basque pelota champions": "أبطال كرة الباسك",
    "fencing racing champions": "أبطال سباق مبارزة سيف الشيش",
    "shooting champions": "أبطال الرماية",
    "nordic combined racing champions": "أبطال سباق التزلج النوردي المزدوج",
    "triathlon champions": "أبطال السباق الثلاثي",
    "kick boxing racing champions": "أبطال سباق الكيك بوكسينغ",
    "speed skating champions": "أبطال التزلج السريع",
    "karate champions": "أبطال الكاراتيه",
    "wheelchair fencing champions": "أبطال مبارزة سيف الشيش على الكراسي المتحركة",
}


@pytest.mark.parametrize("category, expected_key", test_data_1.items(), ids=test_data_1.keys())
@pytest.mark.fast
def test_resolve_team_suffix_1(category: str, expected_key: str) -> None:
    label = resolve_sport_label_unified(category)
    assert label == expected_key


@pytest.mark.parametrize("category, expected_key", data_2.items(), ids=data_2.keys())
@pytest.mark.fast
def test_resolve_team_suffix_2(category: str, expected_key: str) -> None:
    label = resolve_sport_label_unified(category)
    assert label == expected_key


@pytest.mark.parametrize("category, expected_key", data_3.items(), ids=data_3.keys())
@pytest.mark.fast
def test_resolve_team_suffix_3(category: str, expected_key: str) -> None:
    label = resolve_sport_label_unified(category)
    assert label == expected_key


all_test_data = test_data_1 | data_2 | data_3

to_test = [
    ("test_resolve_sport_label_by_jobs_key", all_test_data, resolve_sport_label_unified),
]

test_dump_all = make_dump_test_name_data_callback(to_test, run_same=True)



"""
Tests
"""

import pytest

from ArWikiCats.legacy_bots.legacy_resolvers_bots.country2_label_bot import resolve_part_1_label

fast_data_resolve_part_1_label = [
    {"separator": " by ", "key": "american rock musicians", "output": "موسيقيو روك أمريكيون"},
    {"separator": " by ", "key": "amphibious warfare vessels", "output": "سفن حربية برمائية"},
    {"separator": " by ", "key": "animated television series", "output": "مسلسلات تلفزيونية رسوم متحركة"},
    {"separator": " by ", "key": "anime and manga", "output": "أنمي ومانغا"},
    {"separator": " by ", "key": "australian rules football clubs", "output": "أندية كرة قدم أسترالية"},
    {"separator": " by ", "key": "australian rules football", "output": "كرة القدم الأسترالية"},
    {"separator": " by ", "key": "buildings and structures demolished", "output": "مبان ومنشآت هدمت"},
    {"separator": " by ", "key": "buildings and structures", "output": "مبان ومنشآت"},
    {"separator": " by ", "key": "christian buildings and structures", "output": "مبان ومنشآت مسيحية"},
    {"separator": " by ", "key": "christian music albums", "output": "ألبومات موسيقى مسيحية"},
    {"separator": " by ", "key": "christian universities and colleges", "output": "جامعات وكليات مسيحية"},
    {"separator": " by ", "key": "dance music albums", "output": "ألبومات موسيقى الرقص"},
    {"separator": " by ", "key": "death metal albums", "output": "ألبومات ديث ميتال"},
    {"separator": " by ", "key": "east german people", "output": "ألمانيون شرقيون"},
    {"separator": " by ", "key": "east german sports-people", "output": "رياضيون ألمانيون شرقيون"},
    {"separator": " by ", "key": "eastern orthodox cathedrals", "output": "كاتدرائيات أرثوذكسية شرقية"},
    {"separator": " by ", "key": "english male actors", "output": "ممثلون ذكور إنجليز"},
    {"separator": " by ", "key": "folk rock albums", "output": "ألبومات فولك روك"},
    {"separator": " by ", "key": "hardcore punk albums", "output": "ألبومات هاردكور بانك"},
    {"separator": " by ", "key": "heavy metal albums", "output": "ألبومات هيفي ميتال"},
    {"separator": " by ", "key": "ice hockey leagues", "output": "دوريات هوكي جليد"},
    {"separator": " by ", "key": "ice hockey teams", "output": "فرق هوكي الجليد"},
    {"separator": " by ", "key": "indie pop albums", "output": "ألبومات إيندي بوب"},
    {"separator": " by ", "key": "indie rock albums", "output": "ألبومات إيندي روك"},
    {"separator": " by ", "key": "international baseball competitions", "output": "منافسات كرة قاعدة دولية"},
    {"separator": " by ", "key": "latin music albums", "output": "ألبومات موسيقى لاتينية"},
    {"separator": " by ", "key": "law enforcement operations", "output": "عمليات تطبيق القانون"},
    {"separator": " by ", "key": "major league baseball players", "output": "لاعبو دوري كرة القاعدة الرئيسي"},
    {"separator": " by ", "key": "noise music albums", "output": "ألبومات موسيقى نويز"},
    {"separator": " by ", "key": "olympic games bids", "output": "عروض الألعاب الأولمبية"},
    {"separator": " by ", "key": "palestinian people imprisoned", "output": "فلسطينيون مسجونون"},
    {"separator": " by ", "key": "pop punk albums", "output": "ألبومات بوب بانك"},
    {"separator": " by ", "key": "ports and harbours", "output": "مرافئ وموانئ"},
    {"separator": " by ", "key": "prisoners sentenced to death", "output": "سجناء حكم عليهم بالإعدام"},
    {
        "separator": " by ",
        "key": "prisoners sentenced to life imprisonment",
        "output": "سجناء حكم عليهم بالحبس المؤبد",
    },
    {"separator": " by ", "key": "protestant religious leaders", "output": "قادة دينيون بروتستانتيون"},
    {"separator": " by ", "key": "psychedelic music albums", "output": "ألبومات موسيقى سايكيديلية"},
    {"separator": " by ", "key": "roman catholic archbishops", "output": "رؤساء أساقفة رومان كاثوليك"},
    {"separator": " by ", "key": "roman catholic bishops", "output": "أساقفة كاثوليك رومان"},
    {"separator": " by ", "key": "rugby league coaches", "output": "مدربو دوري رجبي"},
    {"separator": " by ", "key": "science fiction films", "output": "أفلام خيال علمي"},
    {"separator": " by ", "key": "science fiction novels", "output": "روايات خيال علمي"},
    {"separator": " by ", "key": "serbian basketball players", "output": "لاعبو كرة سلة صرب"},
    {"separator": " by ", "key": "sierra leonean people", "output": "سيراليونيون"},
    {"separator": " by ", "key": "south african people", "output": "جنوب إفريقيون"},
    {"separator": " by ", "key": "spoken word albums", "output": "ألبومات كلمة منطوقة"},
    {"separator": " by ", "key": "television series produced", "output": "مسلسلات تلفزيونية أنتجت"},
    {"separator": " by ", "key": "television shows produced", "output": "عروض تلفزيونية أنتجت"},
    {"separator": " by ", "key": "united arab emirates", "output": "الإمارات العربية المتحدة"},
    {"separator": " by ", "key": "united kingdom", "output": "المملكة المتحدة"},
    {"separator": " by ", "key": "united states", "output": "الولايات المتحدة"},
    {"separator": " by ", "key": "united arab emirates", "output": "الإمارات العربية المتحدة"},
    {"separator": " by ", "key": "world heritage sites", "output": "مواقع التراث العالمي"},
    {"separator": " from ", "key": "australian rules footballers", "output": "لاعبو كرة قدم أسترالية"},
    {"separator": " from ", "key": "field hockey people", "output": "أعلام هوكي ميدان"},
    {"separator": " from ", "key": "field hockey players", "output": "لاعبو هوكي ميدان"},
    {"separator": " from ", "key": "ice hockey people", "output": "أعلام هوكي جليد"},
    {"separator": " from ", "key": "male voice actors", "output": "ممثلو أداء صوتي ذكور"},
    {"separator": " from ", "key": "rugby league players", "output": "لاعبو دوري رجبي"},
    {"separator": " from ", "key": "rugby union players", "output": "لاعبو اتحاد رجبي"},
    {"separator": " from ", "key": "united states house-of-representatives", "output": "مجلس النواب الأمريكي"},
    {"separator": " from ", "key": "water polo players", "output": "لاعبو كرة ماء"},
    {"separator": " in ", "key": "universities and colleges", "output": "جامعات وكليات"},
    {"separator": " in ", "key": "video games set", "output": "ألعاب فيديو تقع أحداثها"},
    {"separator": " in ", "key": "world heritage sites", "output": "مواقع التراث العالمي"},
    {"separator": " of ", "key": "archaeological sites of", "output": "مواقع أثرية في"},
    {"separator": " of ", "key": "battles and operations of", "output": "معارك وعمليات"},
    {"separator": " of ", "key": "burial sites of", "output": "مواقع دفن"},
    {"separator": " of ", "key": "canyons and gorges of", "output": "أخاديد في"},
    {"separator": " of ", "key": "chemical technology of", "output": "تقانة كيميائية في"},
    {"separator": " of ", "key": "chief justices of", "output": "رؤساء قضاء"},
    {"separator": " of ", "key": "congressional districts of", "output": "مقاطعات الكونغرس في"},
    {"separator": " of ", "key": "cultural depictions of", "output": "تصوير ثقافي عن"},
    {"separator": " of ", "key": "drainage basins of", "output": "أحواض تصريف في"},
    {"separator": " of ", "key": "eastern front of", "output": "الجبهة الشرقية في"},
    {"separator": " of ", "key": "featured pictures of", "output": "صور مميزة عن"},
    {"separator": " of ", "key": "fictional depictions of", "output": "تصوير خيالي عن"},
    {"separator": " of ", "key": "government ministers of", "output": "وزراء"},
    {"separator": " of ", "key": "governors general of", "output": "حكام عموم"},
    {"separator": " of ", "key": "indigenous peoples of", "output": "شعوب أصلية في"},
    {"separator": " of ", "key": "lieutenant governors of", "output": "نواب حكام"},
    {"separator": " of ", "key": "mass murder of", "output": "قتل جماعي في"},
    {"separator": " of ", "key": "military operations of", "output": "عمليات عسكرية في"},
    {"separator": " of ", "key": "mountain passes of", "output": "ممرات جبلية في"},
    {"separator": " of ", "key": "mountain ranges of", "output": "سلاسل جبلية في"},
    {"separator": " of ", "key": "mountains and hills of", "output": "جبال وتلال"},
    {"separator": " of ", "key": "national parks of", "output": "متنزهات وطنية في"},
    {"separator": " of ", "key": "native birds of", "output": "طيور محلية في"},
    {"separator": " of ", "key": "naval battles of", "output": "معارك بحرية"},
    {"separator": " of ", "key": "peace treaties of", "output": "معاهدات سلام"},
    {"separator": " of ", "key": "ports and harbours of", "output": "مرافئ وموانئ"},
    {"separator": " of ", "key": "prime ministers of", "output": "رؤساء وزراء"},
    {"separator": " of ", "key": "prisoners and detainees of", "output": "سجناء ومعتقلون في"},
    {"separator": " of ", "key": "protected areas of", "output": "مناطق محمية في"},
    {"separator": " of ", "key": "rock formations of", "output": "تكوينات صخرية في"},
    {"separator": " of ", "key": "sports organizations of", "output": "منظمات رياضية في"},
    {"separator": " of ", "key": "state constitutional officers of", "output": "مسؤولون دستوريون في"},
    {"separator": " of ", "key": "order of", "output": "وسام"},
    {"separator": " of ", "key": "uninhabited islands of", "output": "جزر غير مأهولة في"},
    {"separator": " of ", "key": "vice presidents of", "output": "نواب رؤساء"},
    {"separator": " on ", "key": "art museums and galleries", "output": "متاحف فنية ومعارض"},
    {"separator": " on ", "key": "buildings and structures", "output": "مبان ومنشآت"},
    {"separator": " on ", "key": "demolished buildings and structures", "output": "مبان ومنشآت مهدمة"},
    {"separator": " on ", "key": "disused railway stations", "output": "محطات سكك حديدية مهجورة"},
    {"separator": " on ", "key": "military units and formations", "output": "وحدات وتشكيلات عسكرية"},
    {"separator": " on ", "key": "pakistani people imprisoned", "output": "باكستانيون مسجونون"},
    {"separator": " on ", "key": "parks and open spaces", "output": "متنزهات ومساحات مفتوحة"},
    {"separator": " on ", "key": "roman catholic churches", "output": "كنائس رومانية كاثوليكية"},
    {"separator": " on ", "key": "sierra leonean judges", "output": "قضاة سيراليونيون"},
    {"separator": " on ", "key": "south african judges", "output": "قضاة جنوب إفريقيون"},
    {"separator": " on ", "key": "television series set", "output": "مسلسلات تلفزيونية تقع أحداثها"},
    {"separator": " on ", "key": "united states capitol", "output": "كابيتول الولايات المتحدة"},
    {"separator": " on ", "key": "video games set", "output": "ألعاب فيديو تقع أحداثها"},
    {"separator": " to ", "key": "monuments and memorials", "output": "معالم أثرية ونصب تذكارية"},
    {"separator": " to ", "key": "united states navy", "output": "البحرية الأمريكية"},
    {"separator": "-of ", "key": "cabinet secretaries of", "output": "أعضاء مجلس وزراء"},
    {"separator": "-of ", "key": "state cabinet secretaries of", "output": "أعضاء مجلس وزراء"},
]


@pytest.mark.parametrize("data", fast_data_resolve_part_1_label, ids=lambda x: x["key"])
@pytest.mark.fast
def test_resolve_part_1_label(data) -> None:
    """
    Parametrized test that verifies resolve_part_1_label produces the expected Arabic label for a given separator and key.

    Parameters:
        data (dict): Test case mapping with keys:
            - 'separator' (str): string used to join components.
            - 'key' (str): input label/topic to convert.
            - 'output' (str): expected Arabic label.
    """
    label = resolve_part_1_label(data["key"], data["separator"])
    assert label == data["output"]



"""
Main resolution logic for category labels.
This module coordinates different resolvers (pattern-based, new, and legacy)
to translate and normalize Wikipedia category labels into Arabic.
"""

from __future__ import annotations

import functools
import logging
from dataclasses import dataclass

from ..fix import cleanse_category_label, filter_en, fixlabel
from ..format_bots import change_cat
from ..legacy_bots import legacy_resolvers
from ..new_resolvers import all_new_resolvers
from ..patterns_resolvers import all_patterns_resolvers
from ..sub_new_resolvers import university_resolver

logger = logging.getLogger(__name__)


@dataclass
class CategoryResult:
    """Data structure representing each processed category.

    Attributes:
        en: The original English category label.
        ar: The resolved Arabic label, or empty string if not resolved.
        from_match: True if pattern-based match produced the label.
    """

    en: str
    ar: str
    from_match: bool


@functools.lru_cache(maxsize=50000)
def resolve_label(category: str, fix_label: bool = True) -> CategoryResult:
    """Translate an English Wikipedia category label into its Arabic equivalent.

    Parameters
    ----------
    category : str
        The original English category label to translate.
    fix_label : bool, optional
        If True, apply post-resolution label fixes before final cleansing.
        Default is True.

    Returns
    -------
    CategoryResult
        A dataclass containing:
        - ``en``: The original English category label.
        - ``ar``: The resolved Arabic label, or empty string if not resolved.
        - ``from_match``: True if a pattern-based match produced the label.
    """
    changed_cat = change_cat(category)

    if category.isdigit():
        return CategoryResult(
            en=category,
            ar=category,
            from_match=False,
        )

    if changed_cat.isdigit():
        return CategoryResult(
            en=category,
            ar=changed_cat,
            from_match=False,
        )

    is_cat_okay = filter_en.is_category_allowed(category)
    if not is_cat_okay:
        logger.debug(f"Category filtered out: {category}")
        return CategoryResult(
            en=category,
            ar="",
            from_match=False,
        )

    category_lab = all_patterns_resolvers(changed_cat)
    from_match = bool(category_lab)

    # If no pattern match, try the resolver chain
    # The chain works because empty string is falsy - first non-empty result wins
    if not category_lab:
        category_lab = (
            all_new_resolvers(changed_cat)
            or university_resolver.resolve_university_category(changed_cat)
            or legacy_resolvers(changed_cat)
        )
    if category_lab and fix_label:
        category_lab = fixlabel(category_lab, en=category)

    category_lab = cleanse_category_label(category_lab)

    return CategoryResult(
        en=category,
        ar=category_lab,
        from_match=from_match,
    )


def resolve_label_ar(category: str, fix_label: bool = True) -> str:
    """Resolve the Arabic label for a given category."""
    result = resolve_label(category, fix_label=fix_label)
    return result.ar


__all__ = [
    "resolve_label",
    "resolve_label_ar",
]



#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data1 = {
    "Cultural depictions of American men": "تصوير ثقافي عن رجال أمريكيين",
    "Cultural depictions of American people": "التصوير الثقافي للأمريكيين",
    "Cultural depictions of Argentine men": "تصوير ثقافي عن رجال أرجنتينيين",
    "Cultural depictions of Argentine people": "تصوير ثقافي عن أرجنتينيين",
    "Cultural depictions of Assyrian people": "تصوير ثقافي عن آشوريين",
    "Cultural depictions of Australian men": "تصوير ثقافي عن رجال أستراليين",
    "Cultural depictions of Australian people": "تصوير ثقافي عن أستراليين",
    "Cultural depictions of Austrian men": "تصوير ثقافي عن رجال نمساويين",
    "Cultural depictions of Austrian people": "التصوير الثقافي للنمساويين",
    "Cultural depictions of Bangladeshi people": "تصوير ثقافي عن بنغلاديشيين",
    "Cultural depictions of Belgian men": "تصوير ثقافي عن رجال بلجيكيين",
    "Cultural depictions of Belgian people": "تصوير ثقافي عن بلجيكيين",
    "Cultural depictions of Bolivian men": "تصوير ثقافي عن رجال بوليفيين",
    "Cultural depictions of Bolivian people": "تصوير ثقافي عن بوليفيين",
    "Cultural depictions of Bosnia and Herzegovina people": "تصوير ثقافي عن بوسنيين",
    "Cultural depictions of Brazilian people": "تصوير ثقافي عن برازيليين",
    "Cultural depictions of British men": "تصوير ثقافي عن رجال بريطانيين",
    "Cultural depictions of British people": "التصوير الثقافي للبريطانيين",
    "Cultural depictions of Byzantine emperors": "تصوير ثقافي عن أباطرة بيزنطيين",
    "Cultural depictions of Byzantine people": "تصوير ثقافي عن البيزنطيين",
    "Cultural depictions of Canadian people": "تصوير ثقافي عن كنديين",
    "Cultural depictions of Chilean people": "تصوير ثقافي عن تشيليين",
    "Cultural depictions of Chinese men": "تصوير ثقافي عن رجال صينيين",
    "Cultural depictions of Chinese monarchs": "تصوير ثقافي عن ملكيين صينيين",
    "Cultural depictions of Chinese people": "تصوير ثقافي عن صينيين",
    "Cultural depictions of Colombian people": "تصوير ثقافي لكولومبيين",
    "Cultural depictions of Cuban people": "تصوير ثقافي لكوبيين",
    "Cultural depictions of Czech people": "تصوير ثقافي عن تشيكيين",
    "Cultural depictions of Danish monarchs": "تصوير ثقافي عن ملكيين دنماركيين",
    "Cultural depictions of Danish people": "تصوير ثقافي عن دنماركيين",
    "Cultural depictions of Dutch men": "تصوير ثقافي عن رجال هولنديين",
    "Cultural depictions of Dutch people": "تصوير ثقافي لهولنديين",
    "Cultural depictions of Egyptian men": "تصوير ثقافي لرجال مصريين",
    "Cultural depictions of Egyptian people": "تصوير ثقافي لمصريين",
    "Cultural depictions of Ethiopian people": "تصوير ثقافي عن إثيوبيين",
    "Cultural depictions of Filipino people": "تصوير ثقافي عن الفلبينيين",
    "Cultural depictions of French men": "تصوير ثقافي عن رجال فرنسيين",
    "Cultural depictions of French people": "التصوير الثقافي للفرنسيين",
    "Cultural depictions of Greek men": "تصوير ثقافي عن رجال يونانيين",
    "Cultural depictions of Greek monarchs": "تصوير ثقافي عن ملكيين يونانيين",
    "Cultural depictions of Greek people": "تصوير ثقافي ليونانيين",
    "Cultural depictions of Hungarian men": "تصوير ثقافي عن رجال مجريين",
    "Cultural depictions of Hungarian people": "تصوير ثقافي عن مجريين",
    "Cultural depictions of Indian monarchs": "تصوير ثقافي عن ملكيين هنود",
    "Cultural depictions of Iranian men": "تصوير ثقافي عن رجال إيرانيين",
    "Cultural depictions of Iranian people": "تصوير ثقافي عن إيرانيين",
    "Cultural depictions of Iraqi people": "تصوير ثقافي لعراقيين",
    "Cultural depictions of Irish men": "تصوير ثقافي عن رجال أيرلنديين",
    "Cultural depictions of Irish people": "تصوير ثقافي عن أيرلنديين",
    "Cultural depictions of Israeli men": "تصوير ثقافي عن رجال إسرائيليين",
    "Cultural depictions of Israeli people": "تصوير ثقافي للإسرائيليين",
    "Cultural depictions of Italian men": "تصوير ثقافي عن رجال إيطاليين",
    "Cultural depictions of Italian people": "تصوير ثقافي عن إيطاليين",
    "Cultural depictions of Japanese men": "تصوير ثقافي عن رجال يابانيين",
    "Cultural depictions of Japanese people": "التصوير الثقافي لليابانيين",
    "Cultural depictions of Libyan people": "تصوير ثقافي لليبيين",
    "Cultural depictions of Mexican men": "تصوير ثقافي عن رجال مكسيكيين",
    "Cultural depictions of Mexican people": "تصوير ثقافي لمكسيكيين",
    "Cultural depictions of Mongolian people": "تصوير ثقافي لمنغوليين",
    "Cultural depictions of New Zealand people": "تصوير ثقافي عن نيوزيلنديين",
    "Cultural depictions of North Korean people": "تصوير ثقافي عن كوريين شماليين",
    "Cultural depictions of Norwegian men": "تصوير ثقافي عن رجال نرويجيين",
    "Cultural depictions of Norwegian people": "تصوير ثقافي عن نرويجيين",
    "Cultural depictions of Pakistani people": "تصوير ثقافي عن باكستانيين",
    "Cultural depictions of Palestinian men": "تصوير ثقافي عن رجال فلسطينيين",
    "Cultural depictions of Palestinian people": "تصوير ثقافي عن فلسطينيين",
    "Cultural depictions of Polish men": "تصوير ثقافي عن رجال بولنديين",
    "Cultural depictions of Polish people": "تصوير ثقافي لبولنديين",
    "Cultural depictions of Portuguese people": "تصوير ثقافي عن البرتغاليين",
    "Cultural depictions of Romanian people": "تصوير ثقافي عن رومانيين",
    "Cultural depictions of Saudi Arabian men": "تصوير ثقافي عن رجال سعوديين",
    "Cultural depictions of Saudi Arabian people": "تصوير ثقافي لسعوديين",
    "Cultural depictions of Scottish men": "تصوير ثقافي عن رجال إسكتلنديين",
    "Cultural depictions of Scottish people": "تصوير ثقافي عن إسكتلنديين",
    "Cultural depictions of Serbian monarchs": "تصوير ثقافي عن ملكيين صرب",
    "Cultural depictions of South Korean people": "تصوير ثقافي عن كوريين جنوبيين",
    "Cultural depictions of Sri Lankan people": "تصوير ثقافي عن سريلانكيين",
    "Cultural depictions of Swedish men": "تصوير ثقافي عن رجال سويديين",
    "Cultural depictions of Swedish people": "تصوير ثقافي عن سويديين",
    "Cultural depictions of Swiss men": "تصوير ثقافي عن رجال سويسريين",
    "Cultural depictions of Swiss people": "تصوير ثقافي عن سويسريين",
    "Cultural depictions of Thai people": "تصوير ثقافي عن تايلنديين",
    "Cultural depictions of Ugandan people": "تصوير ثقافي عن أوغنديين",
    "Cultural depictions of Ukrainian men": "تصوير ثقافي عن رجال أوكرانيين",
    "Cultural depictions of Ukrainian people": "تصوير ثقافي لأوكرانيين",
    "Cultural depictions of Uruguayan people": "تصوير ثقافي عن أوروغويانيين",
    "Cultural depictions of Venezuelan people": "تصوير ثقافي عن فنزويليين",
    "Cultural depictions of Welsh men": "تصوير ثقافي عن رجال ويلزيين",
    "Cultural depictions of Welsh people": "تصوير ثقافي عن ويلزيين",
    "Cultural depictions of Yugoslav people": "تصوير ثقافي عن يوغسلافيين",
    "Cultural depictions of ancient Greek people": "تصوير ثقافي ليونانيين قدماء",
    "Cultural depictions of architects": "تصوير ثقافي لمعماريين",
    "Cultural depictions of astronomers": "تصوير ثقافي عن فلكيين",
    "Cultural depictions of chemists": "تصوير ثقافي عن كيميائيين",
    "Cultural depictions of comedians": "تصوير ثقافي لكوميديين",
    "Cultural depictions of diplomats": "تصوير ثقافي عن دبلوماسيين",
    "Cultural depictions of economists": "تصوير ثقافي لاقتصاديين",
    "Cultural depictions of journalists": "تصوير ثقافي لصحفيين",
    "Cultural depictions of male monarchs": "تصوير ثقافي عن ملكيين ذكور",
    "Cultural depictions of mathematicians": "تصوير ثقافي عن رياضياتيين",
    "Cultural depictions of military officers": "تصوير ثقافي لضباط عسكريين",
    "Cultural depictions of monarchs": "تصوير ثقافي عن ملكيين",
    "Cultural depictions of musicians": "التصوير الثقافي للموسيقيين",
    "Cultural depictions of occultists": "تصوير ثقافي لغموضيين",
    "Cultural depictions of physicists": "تصوير ثقافي عن فيزيائيين",
    "Cultural depictions of politicians": "تصوير ثقافي لسياسيين",
    "Cultural depictions of religious leaders": "تصوير ثقافي لقادة دينيين",
    "Cultural depictions of sports-people": "تصوير ثقافي لرياضيين",
    "Cultural depictions of the Maccabees": "تصوير ثقافي عن مكابيين",
}

to_test = [
    ("test_cultural_depictions_1", data1),
]


@pytest.mark.parametrize("category,expected", data1.items(), ids=data1.keys())
@pytest.mark.skip2
def test_cultural_depictions_data1(category: str, expected: str) -> None:
    """Test"""
    result = resolve_label_ar(category)
    assert result == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)



"""
Category filtering logic for English Wikipedia categories.
This module defines blacklists and prefixes to identify categories that should
not be processed or translated.
"""

import logging
import re

logger = logging.getLogger(__name__)

CATEGORY_BLACKLIST: list[str] = [
    "Disambiguation",
    "wikiproject",
    "sockpuppets",
    "without a source",
    "images for deletion",
]
# ---
CATEGORY_PREFIX_BLACKLIST: list[str] = [
    "Clean-up",
    "Cleanup",
    "Uncategorized",
    "Unreferenced",
    "Unverifiable",
    "Unverified",
    "Wikipedia",
    "Wikipedia articles",
    "Articles about",
    "Articles containing",
    "Articles covered",
    "Articles lacking",
    "Articles needing",
    "Articles prone",
    "Articles requiring",
    "Articles slanted",
    "Articles sourced",
    "Articles tagged",
    "Articles that",
    "Articles to",
    "Articles with",
    "use ",
    "User pages",
    "Userspace",
]

MONTH_NAMES = [
    "January",
    "February",
    "March",
    "April",
    "May",
    "June",
    "July",
    "August",
    "September",
    "October",
    "November",
    "December",
]


def is_category_allowed(category_name: str) -> bool:
    """Return ``True`` when the English category is allowed for processing."""
    normalized_category = category_name.lower()
    for blocked_fragment in CATEGORY_BLACKLIST:
        if blocked_fragment.lower() in normalized_category:
            logger.info(f"<<lightred>> find ({blocked_fragment}) in category_name")
            return False

    normalized_category = normalized_category.replace("category:", "")
    for blocked_prefix in CATEGORY_PREFIX_BLACKLIST:
        if normalized_category.startswith(blocked_prefix.lower()):
            logger.info(f"<<lightred>> category_name.startswith({blocked_prefix})")
            return False

    for month_name in MONTH_NAMES:
        # match the end of category_name like month \d+
        matt = rf"^.*? from {month_name.lower()} \d+$"
        if re.match(matt, normalized_category):
            logger.info(f"<<lightred>> category_name.match({matt})")
            return False

    return True



"""
Package for resolving language-related categories.
This package provides resolvers for categories involving languages,
including films and books in specific languages, with optional time components.


TODO: use it instead of langs_w.py after adding
    jobs_mens_data,
    Films_key_For_nat,
    Lang_work,

"""

import functools
import logging

from ...new.handle_time_with_callback import handle_year_at_first
from .resolve_languages import _resolve_languages_labels
from .resolve_languages_films import resolve_films_languages_labels

logger = logging.getLogger(__name__)


def fix_keys(category: str) -> str:
    """Normalize language-related category keys by lowercasing and standardizing suffixes.

    Args:
        category: The raw category string.

    Returns:
        The normalized category string.
    """
    category = category.lower().replace("category:", "").replace("'", "")
    category = category.replace("-language ", " language ")
    return category


@functools.lru_cache(maxsize=10000)
def resolve_languages_labels(category: str) -> str:
    category = fix_keys(category)

    result = _resolve_languages_labels(category) or resolve_films_languages_labels(category) or ""

    return result


@functools.lru_cache(maxsize=10000)
def resolve_languages_labels_with_time(category: str) -> str:
    logger.debug(f"<<yellow>> start {category=}")
    category = fix_keys(category)

    result = handle_year_at_first(
        category=category,
        callback=resolve_languages_labels,
        result_format="{sub_result} في {arabic_time}",
    )

    logger.info(f"<<yellow>> end {category=}, {result=}")
    return result


__all__ = [
    "resolve_languages_labels",
    "resolve_languages_labels_with_time",
]



#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data_empty_value = {
    "Scheduled multi-sport events": "أحداث رياضية متعددة مقررة",
    "Defunct multi-sport events": "أحداث رياضية متعددة سابقة",
    "Disabled multi-sport events": "أحداث رياضية متعددة معاقون",
    "Timor-Leste at multi-sport events": "أحداث رياضية متعددة في تيمور الشرقية",
    "Wikipedia categories named after multi-sport events": "تصنيفات سميت بأسماء أحداث رياضية متعددة",
    "Youth multi-sport events": "أحداث رياضية متعددة شبابية",
}

data_0 = {
    "1896 in multi-sport events": "الأحداث الرياضية المتعددة في 1896",
    "1900 in multi-sport events": "الأحداث الرياضية المتعددة في 1900",
    "1904 in multi-sport events": "الأحداث الرياضية المتعددة في 1904",
    "1906 in multi-sport events": "الأحداث الرياضية المتعددة في 1906",
    "1908 in multi-sport events": "الأحداث الرياضية المتعددة في 1908",
    "1912 in multi-sport events": "الأحداث الرياضية المتعددة في 1912",
    "1916 in multi-sport events": "الأحداث الرياضية المتعددة في 1916",
    "1920 in multi-sport events": "الأحداث الرياضية المتعددة في 1920",
    "1924 in multi-sport events": "الأحداث الرياضية المتعددة في 1924",
    "1926 in multi-sport events": "الأحداث الرياضية المتعددة في 1926",
    "1928 in multi-sport events": "الأحداث الرياضية المتعددة في 1928",
    "1930 in multi-sport events": "الأحداث الرياضية المتعددة في 1930",
    "1932 in multi-sport events": "الأحداث الرياضية المتعددة في 1932",
    "1933 in multi-sport events": "الأحداث الرياضية المتعددة في 1933",
    "1934 in multi-sport events": "الأحداث الرياضية المتعددة في 1934",
    "1935 in multi-sport events": "الأحداث الرياضية المتعددة في 1935",
    "1936 in multi-sport events": "الأحداث الرياضية المتعددة في 1936",
    "1938 in multi-sport events": "الأحداث الرياضية المتعددة في 1938",
    "1940 in multi-sport events": "الأحداث الرياضية المتعددة في 1940",
    "1944 in multi-sport events": "الأحداث الرياضية المتعددة في 1944",
    "1946 in multi-sport events": "الأحداث الرياضية المتعددة في 1946",
    "1948 in multi-sport events": "الأحداث الرياضية المتعددة في 1948",
    "1950 in multi-sport events": "الأحداث الرياضية المتعددة في 1950",
    "1951 in multi-sport events": "الأحداث الرياضية المتعددة في 1951",
    "1952 in multi-sport events": "الأحداث الرياضية المتعددة في 1952",
    "1953 in multi-sport events": "الأحداث الرياضية المتعددة في 1953",
    "1954 in multi-sport events": "الأحداث الرياضية المتعددة في 1954",
    "1955 in multi-sport events": "الأحداث الرياضية المتعددة في 1955",
    "1956 in multi-sport events": "الأحداث الرياضية المتعددة في 1956",
    "1957 in multi-sport events": "الأحداث الرياضية المتعددة في 1957",
    "1958 in multi-sport events": "الأحداث الرياضية المتعددة في 1958",
    "1959 in multi-sport events": "الأحداث الرياضية المتعددة في 1959",
    "1960 in multi-sport events": "الأحداث الرياضية المتعددة في 1960",
    "1961 in multi-sport events": "الأحداث الرياضية المتعددة في 1961",
    "1962 in multi-sport events": "الأحداث الرياضية المتعددة في 1962",
    "1963 in multi-sport events": "الأحداث الرياضية المتعددة في 1963",
    "1964 in multi-sport events": "الأحداث الرياضية المتعددة في 1964",
    "1965 in multi-sport events": "الأحداث الرياضية المتعددة في 1965",
    "1966 in multi-sport events": "الأحداث الرياضية المتعددة في 1966",
    "1967 in multi-sport events": "الأحداث الرياضية المتعددة في 1967",
    "1968 in multi-sport events": "الأحداث الرياضية المتعددة في 1968",
    "1969 in multi-sport events": "الأحداث الرياضية المتعددة في 1969",
    "1970 in multi-sport events": "الأحداث الرياضية المتعددة في 1970",
    "1971 in multi-sport events": "الأحداث الرياضية المتعددة في 1971",
    "1972 in multi-sport events": "الأحداث الرياضية المتعددة في 1972",
    "1973 in multi-sport events": "الأحداث الرياضية المتعددة في 1973",
    "1974 in multi-sport events": "الأحداث الرياضية المتعددة في 1974",
    "1975 in multi-sport events": "الأحداث الرياضية المتعددة في 1975",
    "1976 in multi-sport events": "الأحداث الرياضية المتعددة في 1976",
    "1977 in multi-sport events": "الأحداث الرياضية المتعددة في 1977",
    "1978 in multi-sport events": "الأحداث الرياضية المتعددة في 1978",
    "1979 in multi-sport events": "الأحداث الرياضية المتعددة في 1979",
    "1980 in multi-sport events": "الأحداث الرياضية المتعددة في 1980",
    "1981 in multi-sport events": "الأحداث الرياضية المتعددة في 1981",
    "1982 in multi-sport events": "الأحداث الرياضية المتعددة في 1982",
    "1983 in multi-sport events": "الأحداث الرياضية المتعددة في 1983",
    "1984 in multi-sport events": "الأحداث الرياضية المتعددة في 1984",
    "1985 in multi-sport events": "الأحداث الرياضية المتعددة في 1985",
    "1986 in multi-sport events": "الأحداث الرياضية المتعددة في 1986",
    "1987 in multi-sport events": "الأحداث الرياضية المتعددة في 1987",
    "1988 in multi-sport events": "الأحداث الرياضية المتعددة في 1988",
    "1989 in multi-sport events": "الأحداث الرياضية المتعددة في 1989",
    "1990 in multi-sport events": "الأحداث الرياضية المتعددة في 1990",
    "1991 in multi-sport events": "الأحداث الرياضية المتعددة في 1991",
    "1992 in multi-sport events": "الأحداث الرياضية المتعددة في 1992",
    "1993 in multi-sport events": "الأحداث الرياضية المتعددة في 1993",
    "1994 in multi-sport events": "الأحداث الرياضية المتعددة في 1994",
    "1995 in multi-sport events": "الأحداث الرياضية المتعددة في 1995",
    "1996 in multi-sport events": "الأحداث الرياضية المتعددة في 1996",
    "1997 in multi-sport events": "الأحداث الرياضية المتعددة في 1997",
    "1998 in multi-sport events": "الأحداث الرياضية المتعددة في 1998",
    "1999 in multi-sport events": "الأحداث الرياضية المتعددة في 1999",
    "2000 in multi-sport events": "الأحداث الرياضية المتعددة في 2000",
    "2001 in multi-sport events": "الأحداث الرياضية المتعددة في 2001",
    "2002 in multi-sport events": "الأحداث الرياضية المتعددة في 2002",
    "2003 in multi-sport events": "الأحداث الرياضية المتعددة في 2003",
    "2004 in multi-sport events": "الأحداث الرياضية المتعددة في 2004",
    "2005 in multi-sport events": "الأحداث الرياضية المتعددة في 2005",
    "2006 in multi-sport events": "الأحداث الرياضية المتعددة في 2006",
    "2007 in multi-sport events": "الأحداث الرياضية المتعددة في 2007",
    "2008 in multi-sport events": "الأحداث الرياضية المتعددة في 2008",
    "2009 in multi-sport events": "الأحداث الرياضية المتعددة في 2009",
    "2010 in multi-sport events": "الأحداث الرياضية المتعددة في 2010",
    "2011 in multi-sport events": "الأحداث الرياضية المتعددة في 2011",
    "2012 in multi-sport events": "الأحداث الرياضية المتعددة في 2012",
    "2013 in multi-sport events": "الأحداث الرياضية المتعددة في 2013",
    "2014 in multi-sport events": "الأحداث الرياضية المتعددة في 2014",
    "2015 in multi-sport events": "الأحداث الرياضية المتعددة في 2015",
    "2016 in multi-sport events": "الأحداث الرياضية المتعددة في 2016",
    "2017 in multi-sport events": "الأحداث الرياضية المتعددة في 2017",
    "2018 in multi-sport events": "الأحداث الرياضية المتعددة في 2018",
    "2019 in multi-sport events": "الأحداث الرياضية المتعددة في 2019",
    "2020 in multi-sport events": "الأحداث الرياضية المتعددة في 2020",
    "2021 in multi-sport events": "الأحداث الرياضية المتعددة في 2021",
    "2022 in multi-sport events": "الأحداث الرياضية المتعددة في 2022",
    "2024 in multi-sport events": "الأحداث الرياضية المتعددة في 2024",
    "2025 in multi-sport events": "الأحداث الرياضية المتعددة في 2025",
    "2026 in multi-sport events": "الأحداث الرياضية المتعددة في 2026",
    "2028 in multi-sport events": "الأحداث الرياضية المتعددة في 2028",
}


data_1 = {
    "Competitors at multi-sport events by country": "منافسون في أحداث رياضية متعددة حسب البلد",
    "Competitors at multi-sport events by sport": "منافسون في أحداث رياضية متعددة حسب الرياضة",
    "Competitors at multi-sport events by year": "منافسون في أحداث رياضية متعددة حسب السنة",
    "Medalists at multi-sport events by year": "فائزون بميداليات في أحداث رياضية متعددة حسب السنة",
    "Nations at multi-sport events by country": "بلدان في أحداث رياضية متعددة حسب البلد",
    "Albania at winter multi-sport events": "ألبانيا في أحداث رياضية متعددة شتوية",
    "Algeria at winter multi-sport events": "الجزائر في أحداث رياضية متعددة شتوية",
    "American Samoa at winter multi-sport events": "ساموا الأمريكية في أحداث رياضية متعددة شتوية",
    "Argentina at winter multi-sport events": "الأرجنتين في أحداث رياضية متعددة شتوية",
    "Australia at winter multi-sport events": "أستراليا في أحداث رياضية متعددة شتوية",
    "Austria at winter multi-sport events": "النمسا في أحداث رياضية متعددة شتوية",
    "Brazil at winter multi-sport events": "البرازيل في أحداث رياضية متعددة شتوية",
    "Canada at winter multi-sport events": "كندا في أحداث رياضية متعددة شتوية",
    "China at winter multi-sport events": "الصين في أحداث رياضية متعددة شتوية",
    "Czech Republic at winter multi-sport events": "التشيك في أحداث رياضية متعددة شتوية",
    "East Germany at winter multi-sport events": "ألمانيا الشرقية في أحداث رياضية متعددة شتوية",
    "France at winter multi-sport events": "فرنسا في أحداث رياضية متعددة شتوية",
    "Germany at winter multi-sport events": "ألمانيا في أحداث رياضية متعددة شتوية",
    "Hong Kong at winter multi-sport events": "هونغ كونغ في أحداث رياضية متعددة شتوية",
    "India at winter multi-sport events": "الهند في أحداث رياضية متعددة شتوية",
    "Iran at winter multi-sport events": "إيران في أحداث رياضية متعددة شتوية",
    "Israel at winter multi-sport events": "إسرائيل في أحداث رياضية متعددة شتوية",
    "Italy at winter multi-sport events": "إيطاليا في أحداث رياضية متعددة شتوية",
    "Japan at winter multi-sport events": "اليابان في أحداث رياضية متعددة شتوية",
    "Kazakhstan at winter multi-sport events": "كازاخستان في أحداث رياضية متعددة شتوية",
    "Kyrgyzstan at winter multi-sport events": "قيرغيزستان في أحداث رياضية متعددة شتوية",
    "Lebanon at winter multi-sport events": "لبنان في أحداث رياضية متعددة شتوية",
    "Lithuania at winter multi-sport events": "ليتوانيا في أحداث رياضية متعددة شتوية",
    "Malaysia at winter multi-sport events": "ماليزيا في أحداث رياضية متعددة شتوية",
    "Mongolia at winter multi-sport events": "منغوليا في أحداث رياضية متعددة شتوية",
    "Multi-sport events": "أحداث رياضية متعددة",
    "Multi-sport events-related lists": "قوائم متعلقة بأحداث رياضية متعددة",
    "Multi-sport events bids": "ترشيحات أحداث رياضية متعددة",
    "Multi-sport events by country": "أحداث رياضية متعددة حسب البلد",
    "Multi-sport events by year": "أحداث رياضية متعددة حسب السنة",
    "Multi-sport events cancelled due to the COVID-19 pandemic": "أحداث رياضية متعددة ألغيت بسبب جائحة فيروس كورونا",
    "Multi-sport events in Africa by country": "أحداث رياضية متعددة في إفريقيا حسب البلد",
    "Multi-sport events in Andorra": "أحداث رياضية متعددة في أندورا",
    "Multi-sport events in Argentina": "أحداث رياضية متعددة في الأرجنتين",
    "Multi-sport events in Asia": "أحداث رياضية متعددة في آسيا",
    "Multi-sport events in Asia by country": "أحداث رياضية متعددة في آسيا حسب البلد",
    "Multi-sport events in Australia": "أحداث رياضية متعددة في أستراليا",
    "Multi-sport events in Austria": "أحداث رياضية متعددة في النمسا",
    "Multi-sport events in Azerbaijan": "أحداث رياضية متعددة في أذربيجان",
    "Multi-sport events in Bahrain": "أحداث رياضية متعددة في البحرين",
    "Multi-sport events in Belgium": "أحداث رياضية متعددة في بلجيكا",
    "Multi-sport events in Bolivia": "أحداث رياضية متعددة في بوليفيا",
    "Multi-sport events in Brazil": "أحداث رياضية متعددة في البرازيل",
    "Multi-sport events in Bulgaria": "أحداث رياضية متعددة في بلغاريا",
    "Multi-sport events in Canada": "أحداث رياضية متعددة في كندا",
    "Multi-sport events in Chile": "أحداث رياضية متعددة في تشيلي",
    "Multi-sport events in China": "أحداث رياضية متعددة في الصين",
    "Multi-sport events in Colombia": "أحداث رياضية متعددة في كولومبيا",
    "Multi-sport events in Croatia": "أحداث رياضية متعددة في كرواتيا",
    "Multi-sport events in Cuba": "أحداث رياضية متعددة في كوبا",
    "Multi-sport events in Cyprus": "أحداث رياضية متعددة في قبرص",
    "Multi-sport events in Czechoslovakia": "أحداث رياضية متعددة في تشيكوسلوفاكيا",
    "Multi-sport events in Denmark": "أحداث رياضية متعددة في الدنمارك",
    "Multi-sport events in East Germany": "أحداث رياضية متعددة في ألمانيا الشرقية",
    "Multi-sport events in Ecuador": "أحداث رياضية متعددة في الإكوادور",
    "Multi-sport events in El Salvador": "أحداث رياضية متعددة في السلفادور",
    "Multi-sport events in Europe": "أحداث رياضية متعددة في أوروبا",
    "Multi-sport events in Europe by country": "أحداث رياضية متعددة في أوروبا حسب البلد",
    "Multi-sport events in Finland": "أحداث رياضية متعددة في فنلندا",
    "Multi-sport events in France": "أحداث رياضية متعددة في فرنسا",
    "Multi-sport events in Germany": "أحداث رياضية متعددة في ألمانيا",
    "Multi-sport events in Greece": "أحداث رياضية متعددة في اليونان",
    "Multi-sport events in Hungary": "أحداث رياضية متعددة في المجر",
    "Multi-sport events in Iceland": "أحداث رياضية متعددة في آيسلندا",
    "Multi-sport events in India": "أحداث رياضية متعددة في الهند",
    "Multi-sport events in Indonesia": "أحداث رياضية متعددة في إندونيسيا",
    "Multi-sport events in insular areas of the United States": "أحداث رياضية متعددة في المناطق المعزولة في الولايات المتحدة",
    "Multi-sport events in Iran": "أحداث رياضية متعددة في إيران",
    "Multi-sport events in Israel": "أحداث رياضية متعددة في إسرائيل",
    "Multi-sport events in Italy": "أحداث رياضية متعددة في إيطاليا",
    "Multi-sport events in Jamaica": "أحداث رياضية متعددة في جامايكا",
    "Multi-sport events in Japan": "أحداث رياضية متعددة في اليابان",
    "Multi-sport events in Jordan": "أحداث رياضية متعددة في الأردن",
    "Multi-sport events in Kazakhstan": "أحداث رياضية متعددة في كازاخستان",
    "Multi-sport events in Kenya": "أحداث رياضية متعددة في كينيا",
    "Multi-sport events in Kuwait": "أحداث رياضية متعددة في الكويت",
    "Multi-sport events in Lebanon": "أحداث رياضية متعددة في لبنان",
    "Multi-sport events in Liechtenstein": "أحداث رياضية متعددة في ليختنشتاين",
    "Multi-sport events in Luxembourg": "أحداث رياضية متعددة في لوكسمبورغ",
    "Multi-sport events in Macau": "أحداث رياضية متعددة في ماكاو",
    "Multi-sport events in Malaysia": "أحداث رياضية متعددة في ماليزيا",
    "Multi-sport events in Malta": "أحداث رياضية متعددة في مالطا",
    "Multi-sport events in Mexico": "أحداث رياضية متعددة في المكسيك",
    "Multi-sport events in Monaco": "أحداث رياضية متعددة في موناكو",
    "Multi-sport events in Mongolia": "أحداث رياضية متعددة في منغوليا",
    "Multi-sport events in Montenegro": "أحداث رياضية متعددة في الجبل الأسود",
    "Multi-sport events in Mozambique": "أحداث رياضية متعددة في موزمبيق",
    "Multi-sport events in New Zealand": "أحداث رياضية متعددة في نيوزيلندا",
    "Multi-sport events in Nigeria": "أحداث رياضية متعددة في نيجيريا",
    "Multi-sport events in North America": "أحداث رياضية متعددة في أمريكا الشمالية",
    "Multi-sport events in North Korea": "أحداث رياضية متعددة في كوريا الشمالية",
    "Multi-sport events in Norway": "أحداث رياضية متعددة في النرويج",
    "Multi-sport events in Oceania": "أحداث رياضية متعددة في أوقيانوسيا",
    "Multi-sport events in Oman": "أحداث رياضية متعددة في سلطنة عمان",
    "Multi-sport events in Panama": "أحداث رياضية متعددة في بنما",
    "Multi-sport events in Peru": "أحداث رياضية متعددة في بيرو",
    "Multi-sport events in Poland": "أحداث رياضية متعددة في بولندا",
    "Multi-sport events in Puerto Rico": "أحداث رياضية متعددة في بورتوريكو",
    "Multi-sport events in Qatar": "أحداث رياضية متعددة في قطر",
    "Multi-sport events in Romania": "أحداث رياضية متعددة في رومانيا",
    "Multi-sport events in Russia": "أحداث رياضية متعددة في روسيا",
    "Multi-sport events in Samoa": "أحداث رياضية متعددة في ساموا",
    "Multi-sport events in San Marino": "أحداث رياضية متعددة في سان مارينو",
    "Multi-sport events in Serbia": "أحداث رياضية متعددة في صربيا",
    "Multi-sport events in Singapore": "أحداث رياضية متعددة في سنغافورة",
    "Multi-sport events in Slovakia": "أحداث رياضية متعددة في سلوفاكيا",
    "Multi-sport events in South America": "أحداث رياضية متعددة في أمريكا الجنوبية",
    "Multi-sport events in South Korea": "أحداث رياضية متعددة في كوريا الجنوبية",
    "Multi-sport events in Spain": "أحداث رياضية متعددة في إسبانيا",
    "Multi-sport events in Sweden": "أحداث رياضية متعددة في السويد",
    "Multi-sport events in Switzerland": "أحداث رياضية متعددة في سويسرا",
    "Multi-sport events in Syria": "أحداث رياضية متعددة في سوريا",
    "Multi-sport events in Taiwan": "أحداث رياضية متعددة في تايوان",
    "Multi-sport events in Thailand": "أحداث رياضية متعددة في تايلاند",
    "Multi-sport events in the Netherlands": "أحداث رياضية متعددة في هولندا",
    "Multi-sport events in the Republic of the Congo": "أحداث رياضية متعددة في جمهورية الكونغو",
    "Multi-sport events in the Soviet Union": "أحداث رياضية متعددة في الاتحاد السوفيتي",
    "Multi-sport events in the United Kingdom": "أحداث رياضية متعددة في المملكة المتحدة",
    "Multi-sport events in the United States": "أحداث رياضية متعددة في الولايات المتحدة",
    "Multi-sport events in Turkey": "أحداث رياضية متعددة في تركيا",
    "Multi-sport events in Turkmenistan": "أحداث رياضية متعددة في تركمانستان",
    "Multi-sport events in Venezuela": "أحداث رياضية متعددة في فنزويلا",
    "Multi-sport events in Vietnam": "أحداث رياضية متعددة في فيتنام",
    "Multi-sport events in West Germany": "أحداث رياضية متعددة في ألمانيا الغربية",
    "Multi-sport events in Yugoslavia": "أحداث رياضية متعددة في يوغسلافيا",
    "Multi-sport events in Zimbabwe": "أحداث رياضية متعددة في زيمبابوي",
    "Multi-sport events templates": "قوالب أحداث رياضية متعددة",
    "Multi-sport events venues": "ملاعب أحداث رياضية متعددة",
    "National multi-sport events": "أحداث رياضية متعددة وطنية",
    "Nations at winter multi-sport events": "بلدان في أحداث رياضية متعددة شتوية",
    "Nepal at winter multi-sport events": "نيبال في أحداث رياضية متعددة شتوية",
    "New Zealand at winter multi-sport events": "نيوزيلندا في أحداث رياضية متعددة شتوية",
    "North Korea at winter multi-sport events": "كوريا الشمالية في أحداث رياضية متعددة شتوية",
    "Pakistan at winter multi-sport events": "باكستان في أحداث رياضية متعددة شتوية",
    "Philippines at winter multi-sport events": "الفلبين في أحداث رياضية متعددة شتوية",
    "Singapore at winter multi-sport events": "سنغافورة في أحداث رياضية متعددة شتوية",
    "South Korea at winter multi-sport events": "كوريا الجنوبية في أحداث رياضية متعددة شتوية",
    "Spain at winter multi-sport events": "إسبانيا في أحداث رياضية متعددة شتوية",
    "Summer multi-sport events": "أحداث رياضية متعددة صيفية",
    "Tajikistan at winter multi-sport events": "طاجيكستان في أحداث رياضية متعددة شتوية",
    "Thailand at winter multi-sport events": "تايلاند في أحداث رياضية متعددة شتوية",
    "Turkey at winter multi-sport events": "تركيا في أحداث رياضية متعددة شتوية",
    "Ukraine at winter multi-sport events": "أوكرانيا في أحداث رياضية متعددة شتوية",
    "United States at winter multi-sport events": "الولايات المتحدة في أحداث رياضية متعددة شتوية",
    "Uzbekistan at winter multi-sport events": "أوزبكستان في أحداث رياضية متعددة شتوية",
    "West Germany at winter multi-sport events": "ألمانيا الغربية في أحداث رياضية متعددة شتوية",
    "Winter multi-sport events by country": "أحداث رياضية متعددة شتوية حسب البلد",
    "Winter multi-sport events in Germany": "أحداث رياضية متعددة شتوية في ألمانيا",
    "Winter multi-sport events in Norway": "أحداث رياضية متعددة شتوية في النرويج",
    "Winter multi-sport events in Russia": "أحداث رياضية متعددة شتوية في روسيا",
    "Winter multi-sport events in the United States": "أحداث رياضية متعددة شتوية في الولايات المتحدة",
    "Multi-sport clubs in Egypt": "أندية متعددة الرياضات في مصر",
    "Multi-sport clubs in Finland": "أندية متعددة الرياضات في فنلندا",
    "Multi-sport clubs in France": "أندية متعددة الرياضات في فرنسا",
    "Multi-sport clubs in Germany": "أندية متعددة الرياضات في ألمانيا",
    "Multi-sport clubs in Greece": "أندية متعددة الرياضات في اليونان",
    "Multi-sport clubs in Iceland": "أندية متعددة الرياضات في آيسلندا",
    "Multi-sport clubs in India": "أندية متعددة الرياضات في الهند",
    "Soviet Union at multi-sport events": "الاتحاد السوفيتي في الأحداث الرياضية المتعددة",
    "Swaziland at multi-sport events": "سوازيلاند في الأحداث الرياضية المتعددة",
    "Wheelchair tennis at multi-sport events": "كرة المضرب على الكراسي المتحركة في الأحداث الرياضية المتعددة",
    "soviet union in multi-sport events": "الاتحاد السوفيتي في الأحداث الرياضية المتعددة",
    "Afghanistan at multi-sport events": "أفغانستان في الأحداث الرياضية المتعددة",
    "Algeria at multi-sport events": "الجزائر في الأحداث الرياضية المتعددة",
    "Angola at multi-sport events": "أنغولا في الأحداث الرياضية المتعددة",
    "Antigua and Barbuda at multi-sport events": "أنتيغوا وباربودا في الأحداث الرياضية المتعددة",
    "Bahamas at multi-sport events": "باهاماس في الأحداث الرياضية المتعددة",
    "Bahrain at multi-sport events": "البحرين في الأحداث الرياضية المتعددة",
    "Barbados at multi-sport events": "بربادوس في الأحداث الرياضية المتعددة",
    "Belarus at multi-sport events": "روسيا البيضاء في الأحداث الرياضية المتعددة",
    "Belize at multi-sport events": "بليز في الأحداث الرياضية المتعددة",
    "Benin at multi-sport events": "بنين في الأحداث الرياضية المتعددة",
    "Bermuda at multi-sport events": "برمودا في الأحداث الرياضية المتعددة",
    "Bhutan at multi-sport events": "بوتان في الأحداث الرياضية المتعددة",
    "Burkina Faso at multi-sport events": "بوركينا فاسو في الأحداث الرياضية المتعددة",
    "Burundi at multi-sport events": "بوروندي في الأحداث الرياضية المتعددة",
    "Cambodia at multi-sport events": "كمبوديا في الأحداث الرياضية المتعددة",
    "Cameroon at multi-sport events": "الكاميرون في الأحداث الرياضية المتعددة",
    "Cape Verde at multi-sport events": "الرأس الأخضر في الأحداث الرياضية المتعددة",
    "Central African Republic at multi-sport events": "جمهورية إفريقيا الوسطى في الأحداث الرياضية المتعددة",
    "Chad at multi-sport events": "تشاد في الأحداث الرياضية المتعددة",
    "Chess at multi-sport events": "الشطرنج في الأحداث الرياضية المتعددة",
    "Comoros at multi-sport events": "جزر القمر في الأحداث الرياضية المتعددة",
    "Competitors at multi-sport events": "منافسون في الأحداث الرياضية المتعددة",
    "Czech Republic at multi-sport events": "التشيك في الأحداث الرياضية المتعددة",
    "Dependent territories of the United Kingdom at multi-sport events": "أقاليم ما وراء البحار البريطانية في الأحداث الرياضية المتعددة",
    "Djibouti at multi-sport events": "جيبوتي في الأحداث الرياضية المتعددة",
    "Dominica at multi-sport events": "دومينيكا في الأحداث الرياضية المتعددة",
    "Dominican Republic at multi-sport events": "جمهورية الدومينيكان في الأحداث الرياضية المتعددة",
    "Egypt at multi-sport events": "مصر في الأحداث الرياضية المتعددة",
    "Equatorial Guinea at multi-sport events": "غينيا الاستوائية في الأحداث الرياضية المتعددة",
    "Equestrian sports at multi-sport events": "رياضات فروسية في الأحداث الرياضية المتعددة",
    "Eritrea at multi-sport events": "إرتريا في الأحداث الرياضية المتعددة",
    "Eswatini at multi-sport events": "إسواتيني في الأحداث الرياضية المتعددة",
    "Ethiopia at multi-sport events": "إثيوبيا في الأحداث الرياضية المتعددة",
    "Fiji at multi-sport events": "فيجي في الأحداث الرياضية المتعددة",
    "Gabon at multi-sport events": "الغابون في الأحداث الرياضية المتعددة",
    "Ghana at multi-sport events": "غانا في الأحداث الرياضية المتعددة",
    "Gibraltar at multi-sport events": "جبل طارق في الأحداث الرياضية المتعددة",
    "Go at multi-sport events": "غو في الأحداث الرياضية المتعددة",
    "Grenada at multi-sport events": "غرينادا في الأحداث الرياضية المتعددة",
    "Guinea-Bissau at multi-sport events": "غينيا بيساو في الأحداث الرياضية المتعددة",
    "Guinea at multi-sport events": "غينيا في الأحداث الرياضية المتعددة",
    "Guyana at multi-sport events": "غيانا في الأحداث الرياضية المتعددة",
    "Haiti at multi-sport events": "هايتي في الأحداث الرياضية المتعددة",
    "Insular areas of the United States at multi-sport events": "المناطق المعزولة في الولايات المتحدة في الأحداث الرياضية المتعددة",
    "Iraq at multi-sport events": "العراق في الأحداث الرياضية المتعددة",
    "Ivory Coast at multi-sport events": "ساحل العاج في الأحداث الرياضية المتعددة",
    "Ju-jitsu at multi-sport events": "جوجوتسو في الأحداث الرياضية المتعددة",
    "Judo at multi-sport events": "الجودو في الأحداث الرياضية المتعددة",
    "Kiribati at multi-sport events": "كيريباتي في الأحداث الرياضية المتعددة",
    "Kosovo at multi-sport events": "كوسوفو في الأحداث الرياضية المتعددة",
    "Lesotho at multi-sport events": "ليسوتو في الأحداث الرياضية المتعددة",
    "Liberia at multi-sport events": "ليبيريا في الأحداث الرياضية المتعددة",
    "Libya at multi-sport events": "ليبيا في الأحداث الرياضية المتعددة",
    "Malawi at multi-sport events": "ملاوي في الأحداث الرياضية المتعددة",
    "Maldives at multi-sport events": "جزر المالديف في الأحداث الرياضية المتعددة",
    "Mali at multi-sport events": "مالي في الأحداث الرياضية المتعددة",
    "Marshall Islands at multi-sport events": "جزر مارشال في الأحداث الرياضية المتعددة",
    "Mauritania at multi-sport events": "موريتانيا في الأحداث الرياضية المتعددة",
    "Mauritius at multi-sport events": "موريشيوس في الأحداث الرياضية المتعددة",
    "Modern pentathlon at multi-sport events": "الخماسي الحديث في الأحداث الرياضية المتعددة",
    "Moldova at multi-sport events": "مولدوفا في الأحداث الرياضية المتعددة",
    "Morocco at multi-sport events": "المغرب في الأحداث الرياضية المتعددة",
    "Multi-sport events by continent": "أحداث رياضية متعددة حسب القارة",
    "Multi-sport events in Africa": "أحداث رياضية متعددة في إفريقيا",
    "Multi-sport events in Algeria": "أحداث رياضية متعددة في الجزائر",
    "Multi-sport events in Egypt": "أحداث رياضية متعددة في مصر",
    "Multi-sport events in Morocco": "أحداث رياضية متعددة في المغرب",
    "Multi-sport events in Saudi Arabia": "أحداث رياضية متعددة في السعودية",
    "Multi-sport events in Tunisia": "أحداث رياضية متعددة في تونس",
    "Multi-sport events navigational boxes": "صناديق تصفح أحداث رياضية متعددة",
    "Namibia at multi-sport events": "ناميبيا في الأحداث الرياضية المتعددة",
    "Nations at multi-sport events": "بلدان في الأحداث الرياضية المتعددة",
    "Netherlands Antilles at multi-sport events": "جزر الأنتيل الهولندية في الأحداث الرياضية المتعددة",
    "North Macedonia at multi-sport events": "مقدونيا الشمالية في الأحداث الرياضية المتعددة",
    "Palestine at multi-sport events": "فلسطين في الأحداث الرياضية المتعددة",
    "Papua New Guinea at multi-sport events": "بابوا غينيا الجديدة في الأحداث الرياضية المتعددة",
    "Paraguay at multi-sport events": "باراغواي في الأحداث الرياضية المتعددة",
    "Philippines at multi-sport events": "الفلبين في الأحداث الرياضية المتعددة",
    "Rwanda at multi-sport events": "رواندا في الأحداث الرياضية المتعددة",
    "Saint Kitts and Nevis at multi-sport events": "سانت كيتس ونيفيس في الأحداث الرياضية المتعددة",
    "Saint Lucia at multi-sport events": "سانت لوسيا في الأحداث الرياضية المتعددة",
    "Saint Vincent and the Grenadines at multi-sport events": "سانت فنسنت وجزر غرينادين في الأحداث الرياضية المتعددة",
    "Senegal at multi-sport events": "السنغال في الأحداث الرياضية المتعددة",
    "Seychelles at multi-sport events": "سيشل في الأحداث الرياضية المتعددة",
    "Skeleton at multi-sport events": "الزلاجات الصدرية في الأحداث الرياضية المتعددة",
    "Slovenia at multi-sport events": "سلوفينيا في الأحداث الرياضية المتعددة",
    "Snooker at multi-sport events": "السنوكر في الأحداث الرياضية المتعددة",
    "Solomon Islands at multi-sport events": "جزر سليمان في الأحداث الرياضية المتعددة",
    "Somalia at multi-sport events": "الصومال في الأحداث الرياضية المتعددة",
    "South Sudan at multi-sport events": "جنوب السودان في الأحداث الرياضية المتعددة",
    "Sport climbing at multi-sport events": "التسلق في الأحداث الرياضية المتعددة",
    "Sudan at multi-sport events": "السودان في الأحداث الرياضية المتعددة",
    "Surfing at multi-sport events": "الركمجة في الأحداث الرياضية المتعددة",
    "Suriname at multi-sport events": "سورينام في الأحداث الرياضية المتعددة",
    "São Tomé and Príncipe at multi-sport events": "ساو تومي وبرينسيب في الأحداث الرياضية المتعددة",
    "Tanzania at multi-sport events": "تنزانيا في الأحداث الرياضية المتعددة",
    "Tennis at multi-sport events": "كرة المضرب في الأحداث الرياضية المتعددة",
    "The Gambia at multi-sport events": "غامبيا في الأحداث الرياضية المتعددة",
    "Togo at multi-sport events": "توغو في الأحداث الرياضية المتعددة",
    "Tonga at multi-sport events": "تونغا في الأحداث الرياضية المتعددة",
    "Trinidad and Tobago at multi-sport events": "ترينيداد وتوباغو في الأحداث الرياضية المتعددة",
    "Tunisia at multi-sport events": "تونس في الأحداث الرياضية المتعددة",
    "Tuvalu at multi-sport events": "توفالو في الأحداث الرياضية المتعددة",
    "Uganda at multi-sport events": "أوغندا في الأحداث الرياضية المتعددة",
    "Ukraine at multi-sport events": "أوكرانيا في الأحداث الرياضية المتعددة",
    "United Arab Emirates at multi-sport events": "الإمارات العربية المتحدة في الأحداث الرياضية المتعددة",
    "Vanuatu at multi-sport events": "فانواتو في الأحداث الرياضية المتعددة",
    "Wheelchair basketball at multi-sport events": "كرة السلة على الكراسي المتحركة في الأحداث الرياضية المتعددة",
    "Winter multi-sport events": "أحداث رياضية متعددة شتوية",
    "Winter multi-sport events in Austria": "أحداث رياضية متعددة شتوية في النمسا",
    "Winter multi-sport events in Canada": "أحداث رياضية متعددة شتوية في كندا",
    "Xiangqi at multi-sport events": "الشطرنج الصيني في الأحداث الرياضية المتعددة",
}

to_test = [
    ("test_multi_sport_0", data_0),
    ("test_multi_sport_1", data_1),
]


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
def test_multi_sport_0(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)
